package com.unis.project.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.FileQueryVO;
import com.unis.project.common.vo.FileVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title FileFeign
 * @ProjectName 文件 FileFeign
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@FeignClient(name = "project-server")
@Component
@Api(value = "文件 ", tags = "文件")
public interface FileFeign {

	@ApiOperation(value = "文件-下载列表", notes = "参数：数据ID")
	@PostMapping(value = "/fileList/{sjId}")
    public ResponseWrapper getFileListBySjId(@PathVariable("sjId") String sjId);

	@ApiOperation(value = "文件-查询列表", notes = "参数：文件号，文件名称")
	@PostMapping(value = "/fileList")
	public ResponseWrapper getFileList(@RequestBody() FileQueryVO fileQueryVO);

	@ApiOperation(value = "文件-分页查询列表", notes = "参数：文件号，文件名称")
	@PostMapping(value = "/filePage/{pageNum}/{pageSize}")
	public ResponseWrapper getFilePage(@RequestBody FileQueryVO fileQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) ;

	@PostMapping(value = "/file")
	@ApiOperation(value = "文件-新增", notes = "参数：文件信息对象 model")
	public ResponseWrapper insert(@RequestBody FileVO fileVO) ;

	@PutMapping(value = "/file")
	@ApiOperation(value = "文件-更新", notes = "参数：文件信息对象 model")
	public ResponseWrapper update(@RequestBody FileVO fileVO) ;

	@DeleteMapping(value="/file/{id}")
	@ApiOperation(value = "文件-删除", notes = "参数：文件ID")
	public ResponseWrapper delete(@PathVariable("id") Integer id) ;

	@GetMapping(value="/file/{id}")
	@ApiOperation(value = "文件-查询详情", notes = "参数：文件ID")
	public ResponseWrapper getFileInfoById(@PathVariable("id") Integer id) ;

	@PostMapping(value="/file/{id}")
	@ApiOperation(value = "文件-下发", notes = "参数：文件ID")
	public ResponseWrapper updateLowerStatus(@PathVariable("id") Integer id) ;


	@PostMapping(value="/fileListBySjId")
	@ApiOperation(value = "文件-更新文件信息", notes = "参数：fileVOList, sjId")
	ResponseWrapper updateFileList(@RequestParam("sjId") String sjId,
								   @RequestBody List<FileVO> fileVOList) ;


	@PostMapping(value="/fileListByfileVOList")
	@ApiOperation(value = "文件-新增文件信息列表", notes = "参数：fileVOList, sjId")
	ResponseWrapper insertFileList(@RequestParam("sjId") String sjId,
								   @RequestBody List<FileVO> fileVOList) ;

}
