package com.unis.project.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectApplicationVO;
import com.unis.project.common.vo.ProjectQueryVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectApplicationFeign
 * @ProjectName 项目申请 ProjectApplicationFeign
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@FeignClient(name = "project-server")
@Component
@Api(value = "项目申请 ", tags = "项目申请")
public interface ProjectApplicationFeign {

	@ApiOperation(value = "项目申请-查询列表", notes = "参数：项目方案标题，项目年度")
	@PostMapping(value = "/projectApplicationList")
	public ResponseWrapper getProjectApplicationList(@RequestBody ProjectQueryVO projectQueryVO);

	@ApiOperation(value = "项目申请-分页查询列表", notes = "参数：项目方案标题，项目年度")
	@PostMapping(value = "/projectApplicationPage/{pageNum}/{pageSize}")
	public ResponseWrapper getProjectApplicationPage(@RequestBody ProjectQueryVO projectQueryVO ,
													 @PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) ;

	@PostMapping(value = "/projectApplication")
	@ApiOperation(value = "项目申请-新增", notes = "参数：项目申请信息对象 model")
	public ResponseWrapper insert(@RequestBody ProjectApplicationVO projectApplicationVO) ;

	@PutMapping(value = "/projectApplication")
	@ApiOperation(value = "项目申请-更新", notes = "参数：项目申请信息对象 model")
	public ResponseWrapper update(@RequestBody ProjectApplicationVO projectApplicationVO) ;

	@DeleteMapping(value="/projectApplication/{xmsqId}")
	@ApiOperation(value = "项目申请-删除", notes = "参数：项目申请ID")
	public ResponseWrapper delete(@PathVariable("xmsqId") String xmsqId) ;

	@GetMapping(value="/projectApplication/{xmsqId}")
	@ApiOperation(value = "项目申请-查询详情", notes = "参数：项目申请ID")
	public ResponseWrapper getProjectApplicationInfoById(@PathVariable("xmsqId") String xmsqId) ;

	@ApiOperation(value = "项目申请-获取资金申请提交后和验收申请提交前数据", notes = "参数：")
	@PostMapping(value = "/projectApplicationIdList")
	public ResponseWrapper getProjectApplicationIdList();

	@PostMapping(value="/projectApplicationInfoDate")
	@ApiOperation(value = "项目信息-获取当天截止时间的项目申请id", notes = "参数：")
	public ResponseWrapper getProjectInfoDate();
}
