package com.unis.project.client;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.ProjectMaterialDetailsVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectMaterialDetailsFeign
 * @ProjectName 项目材料 ProjectMaterialDetailsFeign
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@FeignClient(name = "project-server")
@Component
@Api(value = "项目材料 ", tags = "项目材料")
public interface ProjectMaterialDetailsFeign {

	@ApiOperation(value = "项目材料-查看列表", notes = "参数：数据ID")
	@PostMapping(value = "/projectMaterialDetailsList/{sjId}")
    public ResponseWrapper getProjectMaterialDetailsListBySjId(@PathVariable("sjId") String sjId);

	@PostMapping(value = "/projectMaterialDetails/{sjId}")
	@ApiOperation(value = "项目材料-新增列表", notes = "参数：项目材料信息列表，数据ID")
	public ResponseWrapper insertProjectMaterialDetailsList(@RequestBody List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList,@PathVariable("sjId") String sjId) ;

	@PutMapping(value = "/projectMaterialDetails/{sjId}")
	@ApiOperation(value = "项目材料-更新列表", notes = "参数：项目材料信息列表，数据ID")
	public ResponseWrapper updateProjectMaterialDetailsList(@RequestBody List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList,@PathVariable("sjId") String sjId) ;

	@PostMapping(value = "/insertProjectMaterialDetails/{sjId}")
	@ApiOperation(value = "项目材料-新增", notes = "参数：项目材料信息，数据ID")
	public ResponseWrapper insert(@RequestBody ProjectMaterialDetailsVO projectMaterialDetailsVO,@PathVariable("sjId") String sjId) ;

	@PutMapping(value = "/updateProjectMaterialDetails")
	@ApiOperation(value = "项目材料-更新", notes = "参数：项目材料信息")
	public ResponseWrapper update(@RequestBody ProjectMaterialDetailsVO projectMaterialDetailsVO) ;

	@ApiOperation(value = "项目材料-查看补充材料列表", notes = "参数：数据ID，项目材料类型，补充材料是否提交")
	@PostMapping(value = "/getProjectMaterialDetailsList")
	public ResponseWrapper getProjectMaterialDetailsList(@RequestBody ProjectMaterialDetailsQueryVO projectMaterialDetailsQueryVO);

	@ApiOperation(value = "项目材料-查看删除数据", notes = "参数：数据ID，项目材料类型，补充材料是否提交，是否删除")
	@PostMapping(value = "/projectMaterialDetailsDeleteList")
	public ResponseWrapper getProjectMaterialDetailsDeleteList(@RequestBody ProjectMaterialDetailsQueryVO projectMaterialDetailsQueryVO);

}
