package com.unis.project.common.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;
import org.springframework.format.annotation.DateTimeFormat;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectApplicationVO
 * @ProjectName 项目申请业务对象
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@SuppressWarnings("serial")
@Getter
@Setter
@Table(name="T_XMSQ")
@ApiModel("项目申请业务对象")
public class ProjectApplicationVO extends BaseVO {

    @ApiModelProperty(value = "项目申请id", notes ="项目申请id", required = false)
    @Id
    @Column(name = "XMSQ_ID")
    private String xmsqId;

    @ApiModelProperty(value = "项目id", notes ="项目id", required = false)
    @Column(name = "XM_ID")
    private String xmId;

    @ApiModelProperty(value = "项目方案标题", notes ="项目方案标题", required = false)
    @Column(name = "XMFABT")
    private String xmfabt;

    @ApiModelProperty(value = "项目年度", notes ="项目年度", required = false)
    @Column(name = "XMND")
    private String xmnd;

    @ApiModelProperty(value = "项目立项状态 1、待上报。2、已申请。3、设计招标。4、建议书已提交。5、建议书已批复。6、可研报告已提交。" +
            "7、可研报告已批复。8、立项审批。9、监理招标。10、建设招标。11、资金申请。12、资金批复。13、项目进度。14、验收申请。15、已验收。16、已截止",
            notes ="项目立项状态 1、待上报。2、已申请。3、设计招标。4、建议书已提交。5、建议书已批复。6、可研报告已提交。7、可研报告已批复。" +
                    "8、立项审批。9、监理招标。10、建设招标。11、资金申请。12、资金批复。13、项目进度。14、验收申请。15、已验收。16、已截止", required = false)
    @Column(name = "XMLXZT")
    private Integer xmlxzt;

    @ApiModelProperty(value = "项目招标状态 3、设计招标。4、建议书已提交。5、建议书已批复。6、可研报告已提交。7、可研报告已批复",
            notes ="项目招标状态 3、设计招标。4、建议书已提交。5、建议书已批复。6、可研报告已提交。7、可研报告已批复", required = false)
    @Column(name = "XMZBZT")
    private Integer xmzbzt;

    @ApiModelProperty(value = "项目招标状态更新时间", notes ="项目招标状态更新时间", required = false)
    @Column(name = "XMZBZT_DATE")
    private Date xmzbztDate;

    @ApiModelProperty(value = "项目申请内容", notes ="项目申请内容", required = false)
    @Column(name = "XMSQNR")
    private String xmsqnr;

    @ApiModelProperty(value = "项目申请单位", notes ="项目申请单位", required = false)
    @Column(name = "XMSQDW")
    private String xmsqdw;

    @ApiModelProperty(value = "组织机构id", notes ="组织机构id", required = false)
    @Column(name = "ORGID")
    private String orgid;

    @ApiModelProperty(value = "发布时间", notes ="发布时间", required = false)
    @Column(name = "FBSJ")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss",timezone = "GMT+8")
    private Date fbsj;

    @ApiModelProperty(value = "项目方案详情", notes ="项目方案详情", required = false)
    @Column(name = "XMFAXQ")
    private String xmfaxq;

    @ApiModelProperty(value = "项目申请条件材料", notes ="项目申请条件材料", required = false)
    private List<ProjectMaterialDetailsVO> xmsqtjList;

    @ApiModelProperty(value = "项目申请材料", notes ="项目申请材料", required = false)
    private List<ProjectMaterialDetailsVO> xmsqclList;

    @ApiModelProperty(value = "拟开工时间", notes ="拟开工时间", required = false)
    @Column(name = "plan_start_time")
    private Date planStartTime;

    @ApiModelProperty(value = "拟建成时间", notes ="拟建成时间", required = false)
    @Column(name = "plan_finish_time")
    private Date planFinishTime;

    @ApiModelProperty(value = "项目类型", notes ="项目类型", required = false)
    @Column(name = "project_type")
    private int projectType;

    @ApiModelProperty(value = "总投资", notes ="总投资", required = false)
    @Column(name = "total_investment")
    private BigDecimal totalInvestment;

    @ApiModelProperty(value = "固定资产投资", notes ="固定资产投资", required = false)
    @Column(name = "fixed_asset_investment")
    private BigDecimal fixedAssetInvestment;

    @ApiModelProperty(value = "中央财政投资", notes ="中央财政投资", required = false)
    @Column(name = "central_investment")
    private BigDecimal centralInvestment;

    @ApiModelProperty(value = "省财政投资", notes ="省财政投资", required = false)
    @Column(name = "province_investment")
    private BigDecimal provinceInvestment;

    @ApiModelProperty(value = "市财政投资", notes ="市财政投资", required = false)
    @Column(name = "city_investment")
    private BigDecimal cityInvestment;

    @ApiModelProperty(value = "银行贷款", notes ="银行贷款", required = false)
    @Column(name = "bank_loan")
    private BigDecimal bankLoan;

    @ApiModelProperty(value = "股票债券", notes ="股票债券", required = false)
    @Column(name = "stock_bond")
    private BigDecimal stockBond;

    @ApiModelProperty(value = "其它资金", notes ="其它资金", required = false)
    @Column(name = "other_funds")
    private BigDecimal otherFunds;

    @ApiModelProperty(value = "省编码", notes ="省编码", required = false)
    @Column(name = "province_code")
    private String provinceCode;

    @ApiModelProperty(value = "省名称", notes ="省名称", required = false)
    @Column(name = "province_name")
    private String provinceName;

    @ApiModelProperty(value = "市编码", notes ="市编码", required = false)
    @Column(name = "city_code")
    private String cityCode;

    @ApiModelProperty(value = "市名称", notes ="市名称", required = false)
    @Column(name = "city_name")
    private String cityName;

    @ApiModelProperty(value = "详细地址", notes ="详细地址", required = false)
    @Column(name = "address")
    private String address;

    @ApiModelProperty(value = "经度", notes ="经度", required = false)
    @Column(name = "addr_lon")
    private float addrLon;

    @ApiModelProperty(value = "纬度", notes ="纬度", required = false)
    @Column(name = "addr_lat")
    private float addrLat;

    @ApiModelProperty(value = "联系人", notes ="联系人", required = false)
    @Column(name = "contacts")
    private String contacts;

    @ApiModelProperty(value = "邮箱", notes ="邮箱", required = false)
    @Column(name = "email")
    private String email;

    @ApiModelProperty(value = "联系方式", notes ="联系方式", required = false)
    @Column(name = "telphone")
    private String telphone;

    @ApiModelProperty(value = "申请内容", notes ="申请内容", required = false)
    @Column(name = "apply_content")
    private String applyContent;


    @ApiModelProperty(value = "项目完整地址", notes ="项目完整地址", required = false)
    @Column(name = "address_full_path")
    private String addressFullPath;


    public ProjectApplicationVO(String xmsqId, String xmId, String xmfabt, String xmnd, Integer xmlxzt, Integer xmzbzt,
                                Date xmzbztDate, String xmsqnr, String xmsqdw, String orgid, Date fbsj, String xmfaxq,
                                List<ProjectMaterialDetailsVO> xmsqtjList, List<ProjectMaterialDetailsVO> xmsqclList,
                                Date planStartTime,
                                Date planFinishTime,
                                Integer projectType,
                                BigDecimal totalInvestment,
                                BigDecimal fixedAssetInvestment,
                                BigDecimal centralInvestment,
                                BigDecimal provinceInvestment,
                                BigDecimal cityInvestment,
                                BigDecimal bankLoan,
                                BigDecimal stockBond,
                                BigDecimal otherFunds,
                                String provinceCode,
                                String cityCode,
                                String address,
                                Float addrLon,
                                Float addrLat,
                                String contacts,
                                String email,
                                String telphone,
                                String applyContent,
                                String addressFullPath,
                                String provinceName,
                                String cityName
    ) {
        super();
        this.xmsqId = xmsqId;
        this.xmId = xmId;
        this.xmfabt = xmfabt;
        this.xmnd = xmnd;
        this.xmlxzt = xmlxzt;
        this.xmzbzt = xmzbzt;
        this.xmzbztDate = xmzbztDate;
        this.xmsqnr = xmsqnr;
        this.xmsqdw = xmsqdw;
        this.orgid = orgid;
        this.fbsj = fbsj;
        this.xmfaxq = xmfaxq;
        this.xmsqtjList = xmsqtjList;
        this.xmsqclList = xmsqclList;
        this.planStartTime = planStartTime;
        this.planFinishTime = planFinishTime;
        this.projectType = projectType;
        this.totalInvestment = totalInvestment;
        this.fixedAssetInvestment = fixedAssetInvestment;
        this.centralInvestment = centralInvestment;
        this.provinceInvestment = provinceInvestment;
        this.cityInvestment = cityInvestment;
        this.bankLoan = bankLoan;
        this.stockBond = stockBond;
        this.otherFunds = otherFunds;
        this.provinceCode = provinceCode;
        this.provinceName = provinceName;
        this.cityCode = cityCode;
        this.cityName = cityName;
        this.address = address;
        this.addrLon = addrLon;
        this.addrLat = addrLat;
        this.contacts = contacts;
        this.email = email;
        this.telphone = telphone;
        this.applyContent = applyContent;
        this.addressFullPath = addressFullPath;
    }

    public ProjectApplicationVO() {
    }

}