package com.unis.project.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.FileQueryVO;
import com.unis.project.common.vo.FileVO;
import com.unis.project.server.service.FileService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
//import oracle.jdbc.proxy.annotation.Post;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title FileController
 * @ProjectName 文件 FileController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "文件 ", tags = "文件")
@Slf4j
public class FileController {

	@Autowired
	private FileService fileService;

	/**
	 * @author WangZL
	 * @Description 文件-下载列表
	 * @param 数据ID
	 * @return
	 */
	@ApiOperation(value = "文件-下载列表", notes = "参数：数据ID")
	@PostMapping(value = "/fileList/{sjId}")
    public ResponseWrapper getFileListBySjId(@PathVariable("sjId") String sjId){
		try {
			List<FileVO> fileList = fileService.getFileListBySjId(sjId);
			if(fileList == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "没有文件可供下载", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), fileList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 文件-查询列表
	 * @param 文件号，文件名称
	 * @return 文件列表
	 */
	@ApiOperation(value = "文件-查询列表", notes = "参数：文件号，文件名称")
	@PostMapping(value = "/fileList")
	public ResponseWrapper getFileList(@RequestBody FileQueryVO fileQueryVO){
		try {
			List<FileVO> fileList = fileService.getFileList(fileQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), fileList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 文件-分页查询列表
	 * @param 文件号，文件名称
	 * @return
	 */
	@ApiOperation(value = "文件-分页查询列表", notes = "参数：文件号，文件名称")
	@PostMapping(value = "/filePage/{pageNum}/{pageSize}")
	public ResponseWrapper getFilePage(@RequestBody FileQueryVO fileQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<FileVO> pageInfos = new PageInfo<FileVO>(fileService.getFilePage(fileQueryVO,pageNum,pageSize));
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 文件-新增
	 * @param 文件信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/file")
	@ApiOperation(value = "文件-新增", notes = "参数：文件信息对象 model")
	public ResponseWrapper insert(@RequestBody FileVO fileVO) {
		try{
			FileVO fileVOs = fileService.insert(fileVO);
			if(fileVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增文件失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), fileVOs);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 文件-更新
	 * @param 文件信息对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/file")
	@ApiOperation(value = "文件-更新", notes = "参数：文件信息对象 model")
	public ResponseWrapper update(@RequestBody FileVO fileVO) {
		try{
			int x = fileService.update(fileVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该文件信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该文件信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 文件-删除
	 * @param 文件ID
	 * @return 状态
	 */
	@DeleteMapping(value="/file/{id}")
	@ApiOperation(value = "文件-删除", notes = "参数：文件ID")
	public ResponseWrapper delete(@PathVariable("id") Integer id) {
		try{
			int x = fileService.delete(id);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请文件ID是否正确", null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 文件-查询详情
	 * @param 文件ID
	 * @return 状态
	 */
	@GetMapping(value="/file/{id}")
	@ApiOperation(value = "文件-查询详情", notes = "参数：文件ID")
	public ResponseWrapper getFileInfoById(@PathVariable("id") Integer id) {
		try{
			FileVO fileVO = fileService.getFileInfoById(id);
			if(fileVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，文件不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), fileVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 文件-提交发布
	 * @param 文件ID
	 * @return 状态
	 */
	@PostMapping(value="/file/{id}")
	@ApiOperation(value = "文件-下发", notes = "参数：文件ID")
	public ResponseWrapper updateLowerStatus(@PathVariable("id") Integer id) {
		try{
			int x = fileService.updateLowerStatus(id);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请文件ID是否正确", null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}


	/**
	 * @author 邹杰利
	 * @Description 文件-更新文件信息
	 * @param fileVOList
	 * @return
	 */
	@PostMapping(value="/fileListBySjId")
	@ApiOperation(value = "文件-更新文件信息", notes = "参数：fileVOList, sjId")
	public ResponseWrapper updateFileList(@RequestParam("sjId") String sjId,
										  @RequestBody List<FileVO> fileVOList) {
		try {
			fileService.updateFileList(fileVOList, sjId);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),"更新成功");
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
		}
	}

	/**
	 * @author 邹杰利
	 * @Description 文件-新增文件信息列表
	 * @param fileVOList
	 * @return
	 */
	@PostMapping(value="/fileListByfileVOList")
	@ApiOperation(value = "文件-新增文件信息列表", notes = "参数：文件列表, 数据ID")
	public ResponseWrapper insertFileList(@RequestParam("sjId") String sjId,
										  @RequestBody List<FileVO> fileVOList) {
		try {
			fileService.insertFileList(fileVOList, sjId);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),"新增成功");
		} catch (Exception e) {
			log.error(e.getMessage());
			return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
		}
	}
}
