package com.unis.project.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectApplicationVO;
import com.unis.project.common.vo.ProjectQueryVO;
import com.unis.project.server.service.ProjectApplicationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectApplicationController
 * @ProjectName 项目申请 ProjectApplicationController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "项目申请 ", tags = "项目申请")
@Slf4j
public class ProjectApplicationController {

	@Autowired
	private ProjectApplicationService projectApplicationService;

	/**
	 * @author WangZL
	 * @Description 项目申请-查询列表
	 * @param 项目方案标题，项目年度
	 * @return 项目申请列表
	 */
	@ApiOperation(value = "项目申请-查询列表", notes = "参数：项目方案标题，项目年度")
	@PostMapping(value = "/projectApplicationList")
	public ResponseWrapper getProjectApplicationList(@RequestBody ProjectQueryVO projectQueryVO){
		try {
			List<ProjectApplicationVO> projectApplicationList = projectApplicationService.getProjectApplicationList(projectQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectApplicationList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目申请-分页查询列表
	 * @param 项目方案标题，项目年度
	 * @return
	 */
	@ApiOperation(value = "项目申请-分页查询列表", notes = "参数：项目方案标题，项目年度")
	@PostMapping(value = "/projectApplicationPage/{pageNum}/{pageSize}")
	public ResponseWrapper getProjectApplicationPage(@RequestBody ProjectQueryVO projectQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<ProjectApplicationVO> pageInfos = new PageInfo<ProjectApplicationVO>(projectApplicationService.getProjectApplicationPage(projectQueryVO,pageNum,pageSize));
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目申请-新增
	 * @param 项目申请信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/projectApplication")
	@ApiOperation(value = "项目申请-新增", notes = "参数：项目申请信息对象 model")
	public ResponseWrapper insert(@RequestBody ProjectApplicationVO projectApplicationVO) {
		try{
			if(StringUtils.isEmpty(projectApplicationVO.getXmId())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			ProjectApplicationVO projectApplicationVOs = projectApplicationService.insert(projectApplicationVO);
			if(projectApplicationVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增项目申请失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectApplicationVOs);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目申请-更新
	 * @param 项目申请信息对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/projectApplication")
	@ApiOperation(value = "项目申请-更新", notes = "参数：项目申请信息对象 model")
	public ResponseWrapper update(@RequestBody ProjectApplicationVO projectApplicationVO) {
		try{
			if(StringUtils.isEmpty(projectApplicationVO.getXmId())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			int x = projectApplicationService.update(projectApplicationVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目申请信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目申请信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目申请-删除
	 * @param 项目申请ID
	 * @return 状态
	 */
	@DeleteMapping(value="/projectApplication/{xmsqId}")
	@ApiOperation(value = "项目申请-删除", notes = "参数：项目申请ID")
	public ResponseWrapper delete(@PathVariable("xmsqId") String xmsqId) {
		try{
			int x = projectApplicationService.delete(xmsqId);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请项目申请ID是否正确", null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目申请-查询详情
	 * @param 项目申请ID
	 * @return 状态
	 */
	@GetMapping(value="/projectApplication/{xmsqId}")
	@ApiOperation(value = "项目申请-查询详情", notes = "参数：项目申请ID")
	public ResponseWrapper getProjectApplicationInfoById(@PathVariable("xmsqId") String xmsqId) {
		try{
			ProjectApplicationVO projectApplicationVO = projectApplicationService.getProjectApplicationInfoById(xmsqId);
			if(projectApplicationVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，项目申请不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectApplicationVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目申请-获取资金申请提交后和验收申请提交前数据
	 * @return
	 */
	@ApiOperation(value = "项目申请-获取资金申请提交后和验收申请提交前数据", notes = "参数：")
	@PostMapping(value = "/projectApplicationIdList")
	public ResponseWrapper getProjectApplicationIdList(){
		try {
			List<String> xmsqIdList = projectApplicationService.getProjectApplicationIdList();
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), xmsqIdList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目信息-获取当天截止时间的项目申请id
	 * @return 状态
	 */
	@PostMapping(value="/projectApplicationInfoDate")
	@ApiOperation(value = "项目申请-获取当天截止时间的项目申请id", notes = "参数：")
	public ResponseWrapper getProjectInfoDate() {
		try{
			List<String> xmsqIdList = projectApplicationService.getProjectInfoDate();
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),xmsqIdList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
}
