package com.unis.project.server.controller;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectApprovalAcceptanceVO;
import com.unis.project.common.vo.backlog.BacklogAddVO;
import com.unis.project.server.service.ProjectApprovalAcceptanceService;
import com.unis.project.server.service.mq.BacklogMQService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectApprovalAcceptanceController
 * @ProjectName 项目立项验收 ProjectApprovalAcceptanceController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "项目立项验收 ", tags = "项目立项验收")
@Slf4j
public class ProjectApprovalAcceptanceController {

	@Autowired
	private ProjectApprovalAcceptanceService projectApprovalAcceptanceService;
	@Autowired
	private BacklogMQService mqService;
	/**
	 * @author WangZL
	 * @Description 项目立项验收-新增
	 * @param 项目立项验收信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/projectApprovalAcceptance")
	@ApiOperation(value = "项目立项验收-新增", notes = "参数：项目立项验收信息对象 model")
	public ResponseWrapper insert(@RequestBody ProjectApprovalAcceptanceVO projectApprovalAcceptanceVO) {
		try{
			if(StringUtils.isEmpty(projectApprovalAcceptanceVO.getXmsqId())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			} else if (projectApprovalAcceptanceVO.getXmlxlx() == null){
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			ProjectApprovalAcceptanceVO projectApprovalAcceptanceVOs = projectApprovalAcceptanceService.insert(projectApprovalAcceptanceVO);
			if(projectApprovalAcceptanceVOs == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增项目立项验收失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectApprovalAcceptanceVOs);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目立项验收-更新
	 * @param 项目立项验收信息对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/projectApprovalAcceptance")
	@ApiOperation(value = "项目立项验收-更新", notes = "参数：项目立项验收信息对象 model")
	public ResponseWrapper update(@RequestBody ProjectApprovalAcceptanceVO projectApprovalAcceptanceVO) {
		try{
            if(StringUtils.isEmpty(projectApprovalAcceptanceVO.getXmsqId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (projectApprovalAcceptanceVO.getXmlxlx() == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
			int x = projectApprovalAcceptanceService.update(projectApprovalAcceptanceVO);
			if(x>0) {
			/*	//======================张新亮 添加代办 start========================
				System.out.println("*************进入创建待办************");
				BacklogAddVO record=new BacklogAddVO();
				record.setSubmitter(projectApprovalAcceptanceVO.getRefresher());
				record.setSubmitterId(projectApprovalAcceptanceVO.getRefresherCode());
				record.setCompanyName(projectApprovalAcceptanceVO.getOrgName());
				record.buildAddVO(record);
				record.setItemId(projectApprovalAcceptanceVO.getXmsqId());
				record.setItemName(projectApprovalAcceptanceVO.getItemName());
				record.setItemUrl(projectApprovalAcceptanceVO.getUrl());
				// 另起线程执行待办
				new Thread(new Runnable() {
					@Override
					public void run() {
						System.out.println("********************接收人88*******************");
						System.out.println("-----" + projectApprovalAcceptanceVO.getRefresher() + "-------" + projectApprovalAcceptanceVO.getRefresherCode());
						System.out.println("********************************************");
						record.setReceiver(projectApprovalAcceptanceVO.getRefresher());
						record.setReceiverId(projectApprovalAcceptanceVO.getRefresherCode());
						// 需要将对象序列化成JSONObject
						mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
					}
				}).start();*/
				//======================张新亮 添加代办 end========================
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目立项验收信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目立项验收信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目立项验收-查询详情
	 * @param 项目申请id，项目立项类型xmlxlx：1、立项审批。2、项目验收
	 * @return 状态
	 */
	@GetMapping(value="/projectApprovalAcceptance/{xmsqId}/{xmlxlx}")
	@ApiOperation(value = "项目立项验收-查询详情", notes = "参数：项目申请id，项目立项类型xmlxlx：1、立项审批。2、项目验收")
	public ResponseWrapper getProjectApprovalAcceptanceInfoById(@PathVariable("xmsqId") String xmsqId,@PathVariable("xmlxlx") Integer xmlxlx) {
		try{
            if(StringUtils.isEmpty(xmsqId)) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (xmlxlx == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
			ProjectApprovalAcceptanceVO projectApprovalAcceptanceVO = projectApprovalAcceptanceService.getProjectApprovalAcceptanceInfoById(xmsqId,xmlxlx);
			if(projectApprovalAcceptanceVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，项目立项验收不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectApprovalAcceptanceVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
	
}
