package com.unis.project.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectBidingVO;
import com.unis.project.server.service.ProjectBiddingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/10/25 17:42
 * Version 1.0
 */
@RestController
@Slf4j
@Api(value = "项目管理-招标", tags = "项目管理-招标")
public class ProjectBiddingController {

    @Autowired
    private ProjectBiddingService projectBiddingService;

    @ApiOperation(value = "招标信息-查询详情", notes = "参数：项目招标类型:XMZBLX（1、设计招标。2、监理招标。3、建设招标）, 项目申请id:xmsqId")
    @PostMapping(value = "/projectBiddingDetail/{xmsqId}/{xmzblx}")
    public ResponseWrapper getProjectBiddingDetail(@PathVariable("xmsqId") String xmsqId,@PathVariable("xmzblx") Integer xmzblx){
        try {
            if(StringUtils.isEmpty(xmsqId)) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (xmzblx == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            ProjectBidingVO projectBidingVO = projectBiddingService.getProjectBiddingDetail(xmsqId,xmzblx);
            if(projectBidingVO == null) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，项目招标不存在", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectBidingVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }


    @ApiOperation(value = "招标信息-新增", notes = "参数：ProjectBidingVO")
    @PostMapping(value = "/projectBidding")
    public ResponseWrapper insertProjectBidding(@RequestBody ProjectBidingVO projectBidingVO){
        try {
            if(StringUtils.isEmpty(projectBidingVO.getXmsqId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (projectBidingVO.getXmzblx() == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            ProjectBidingVO projectBidingVOs = projectBiddingService.insertProjectBidding(projectBidingVO);
            if (projectBidingVOs == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增招标信息失败，请重新输入", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectBidingVOs);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "招标信息-更新", notes = "参数：ProjectBidingVO")
    @PutMapping(value = "/projectBidding")
    public ResponseWrapper updateProjectBidding(@RequestBody ProjectBidingVO projectBidingVO){
        try {
            if(StringUtils.isEmpty(projectBidingVO.getXmsqId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (projectBidingVO.getXmzblx() == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            int x = projectBiddingService.updateProjectBidding(projectBidingVO);
            if(x>0) {
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
            } else if (x==0) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目招标信息不存在", null);
            } else {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目招标信息已被作废，不能进行更新",null);
            }
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
}
