package com.unis.project.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectFundApplicationVO;
import com.unis.project.server.service.ProjectFundApplicationService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/10/25 17:42
 * Version 1.0
 */
@RestController
@Slf4j
@Api(value = "项目管理-资金申请", tags = "项目管理-资金申请")
public class ProjectFundApplicationController {

    @Autowired
    private ProjectFundApplicationService projectFundApplicationService;

    @PostMapping(value = "/insertProjectFundApplicationList")
    @ApiOperation(value = "资金申请-新增", notes = "参数：资金申请信息对象 model")
    public ResponseWrapper insertProjectFundApplicationList(@RequestBody List<ProjectFundApplicationVO> projectFundApplicationVOList) {
        try {
            List<ProjectFundApplicationVO> projectFundApplicationList = projectFundApplicationService.insertProjectFundApplicationList(projectFundApplicationVOList);
            if (projectFundApplicationList == null) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增资金申请失败，请重新输入", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectFundApplicationList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
    }

    @PostMapping(value = "/updateProjectFundApplicationList")
    @ApiOperation(value = "资金申请-更新", notes = "参数：资金申请信息对象 model")
    public ResponseWrapper updateProjectFundApplicationList(@RequestBody List<ProjectFundApplicationVO> projectFundApplicationVOList) {
        try {
            int x = projectFundApplicationService.updateProjectFundApplicationList(projectFundApplicationVOList);
            if (x > 0) {
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
            } else if (x == 0) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该资金申请信息不存在", null);
            } else {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该资金申请信息已被作废，不能进行更新", null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
    }

    @GetMapping(value = "/projectFundApplicationList/{xmsqId}")
    @ApiOperation(value = "资金申请-查询详情", notes = "参数：项目申请id")
    public ResponseWrapper getProjectFundApplicationInfoById(@PathVariable("xmsqId") String xmsqId) {
        try {
            List<ProjectFundApplicationVO> projectFundApplicationVOList = projectFundApplicationService.getProjectFundApplicationInfoById(xmsqId);
            if (projectFundApplicationVOList == null) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，资金申请不存在", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectFundApplicationVOList);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "服务错误，请联系管理员");
    }

}