package com.unis.project.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.ProjectMaterialDetailsVO;
import com.unis.project.server.service.ProjectMaterialDetailsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectMaterialDetailsController
 * @ProjectName 项目材料 ProjectMaterialDetailsController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "项目材料 ", tags = "项目材料")
@Slf4j
public class ProjectMaterialDetailsController {

	@Autowired
	private ProjectMaterialDetailsService projectMaterialDetailsService;

	/**
	 * @author WangZL
	 * @Description 项目材料-查看列表
	 * @param 数据ID
	 * @return
	 */
	@ApiOperation(value = "项目材料-查看列表", notes = "参数：数据ID")
	@PostMapping(value = "/projectMaterialDetailsList/{sjId}")
    public ResponseWrapper getProjectMaterialDetailsListBySjId(@PathVariable("sjId") String sjId){
		try {
			List<ProjectMaterialDetailsVO> ProjectMaterialDetailsList = projectMaterialDetailsService.getProjectMaterialDetailsListBySjId(sjId);
			if(ProjectMaterialDetailsList == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "没有项目材料可供展示", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), ProjectMaterialDetailsList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 项目材料-新增列表
	 * @param 项目材料信息列表，数据ID
	 * @return 新增状态
	 */
	@PostMapping(value = "/projectMaterialDetails/{sjId}")
	@ApiOperation(value = "项目材料-新增列表", notes = "参数：项目材料信息列表，数据ID")
	public ResponseWrapper insertProjectMaterialDetailsList(@RequestBody List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList,@PathVariable("sjId") String sjId) {
		try{
			List<ProjectMaterialDetailsVO> projectMaterialDetailsVOLists = projectMaterialDetailsService.insertProjectMaterialDetailsList(projectMaterialDetailsVOList,sjId);
			if(projectMaterialDetailsVOLists == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增项目材料失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectMaterialDetailsVOLists);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

    /**
     * @author WangZL
     * @Description 项目材料-新增
     * @param 项目材料信息，数据ID
     * @return 新增状态
     */
    @PostMapping(value = "/insertProjectMaterialDetails/{sjId}")
    @ApiOperation(value = "项目材料-新增", notes = "参数：项目材料信息，数据ID")
    public ResponseWrapper insert(@RequestBody ProjectMaterialDetailsVO projectMaterialDetailsVO,@PathVariable("sjId") String sjId) {
        try{
            if (StringUtils.isEmpty(sjId)){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (StringUtils.isEmpty(projectMaterialDetailsVO.getXmsqId())){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            int x = projectMaterialDetailsService.insert(projectMaterialDetailsVO,sjId);
            if(x > 0) {
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), null);
            } else {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增项目材料失败，请重新输入", null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

    /**
     * @author WangZL
     * @Description 项目材料-更新
     * @param 项目材料信息
     * @return 新增状态
     */
    @PutMapping(value = "/updateProjectMaterialDetails")
    @ApiOperation(value = "项目材料-更新", notes = "参数：项目材料信息")
    public ResponseWrapper update(@RequestBody ProjectMaterialDetailsVO projectMaterialDetailsVO) {
        try{
            if (StringUtils.isEmpty(projectMaterialDetailsVO.getSjId())){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (StringUtils.isEmpty(projectMaterialDetailsVO.getXmsqId())){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            int x = projectMaterialDetailsService.update(projectMaterialDetailsVO);
            if(x>0) {
                return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
            } else if (x==0) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目材料信息不存在", null);
            } else {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目材料信息已被作废，不能进行更新",null);
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error(e.getMessage());
        }
        return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
    }

	/**
	 * @author WangZL
	 * @Description 项目材料-更新列表
	 * @param 项目材料信息列表，数据ID
	 * @return 新增状态
	 */
	@PutMapping(value = "/projectMaterialDetails/{sjId}")
	@ApiOperation(value = "项目材料-更新列表", notes = "参数：项目材料信息列表，数据ID")
	public ResponseWrapper updateProjectMaterialDetailsList(@RequestBody List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList,@PathVariable("sjId") String sjId) {
		try{
			int x = projectMaterialDetailsService.updateProjectMaterialDetailsList(projectMaterialDetailsVOList,sjId);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目材料信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目材料信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目材料-查看补充材料列表
	 * @param 数据ID，项目材料类型，补充材料是否提交，是否删除
	 * @return
	 */
	@ApiOperation(value = "项目材料-查看补充材料列表", notes = "参数：数据ID，项目材料类型，补充材料是否提交，是否删除")
	@PostMapping(value = "/getProjectMaterialDetailsList")
	public ResponseWrapper getProjectMaterialDetailsList(@RequestBody ProjectMaterialDetailsQueryVO projectMaterialDetailsQueryVO){
		try {
            if(StringUtils.isEmpty(projectMaterialDetailsQueryVO.getSjId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (projectMaterialDetailsQueryVO.getXmcllx() == null){
            	return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			List<ProjectMaterialDetailsVO> ProjectMaterialDetailsList = projectMaterialDetailsService.getProjectMaterialDetailsList(projectMaterialDetailsQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), ProjectMaterialDetailsList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目材料-查看删除数据
	 * @param 数据ID，项目材料类型，补充材料是否提交，是否删除
	 * @return
	 */
	@ApiOperation(value = "项目材料-查看删除数据", notes = "参数：数据ID，项目材料类型，补充材料是否提交，是否删除")
	@PostMapping(value = "/projectMaterialDetailsDeleteList")
	public ResponseWrapper getProjectMaterialDetailsDeleteList(@RequestBody ProjectMaterialDetailsQueryVO projectMaterialDetailsQueryVO){
		try {
			if(StringUtils.isEmpty(projectMaterialDetailsQueryVO.getSjId())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			} else if (projectMaterialDetailsQueryVO.getXmcllx() == null){
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			List<ProjectMaterialDetailsVO> ProjectMaterialDetailsList = projectMaterialDetailsService.getProjectMaterialDetailsDeleteList(projectMaterialDetailsQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), ProjectMaterialDetailsList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
}
