package com.unis.project.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectMonthlyProgressReportQueryVO;
import com.unis.project.common.vo.ProjectMonthlyProgressReportVO;
import com.unis.project.server.service.ProjectMonthlyProgressReportService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectMonthlyProgressReportController
 * @ProjectMonthlyProgressReportName 进度月报 ProjectMonthlyProgressReportController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "进度月报 ", tags = "进度月报")
@Slf4j
public class ProjectMonthlyProgressReportController {

	@Autowired
	private ProjectMonthlyProgressReportService projectMonthlyProgressReportService;

	/**
	 * @author WangZL
	 * @Description 进度月报-查询列表
	 * @param 进度月报，是否调整
	 * @return 进度月报列表
	 */
	@ApiOperation(value = "进度月报-查询列表", notes = "参数：进度月报，是否调整")
	@PostMapping(value = "/projectMonthlyProgressReportList")
	public ResponseWrapper getProjectMonthlyProgressReportList(@RequestBody ProjectMonthlyProgressReportQueryVO projectMonthlyProgressReportQueryVO){
		try {
			List<ProjectMonthlyProgressReportVO> projectMonthlyProgressReportList = projectMonthlyProgressReportService.getProjectMonthlyProgressReportList(projectMonthlyProgressReportQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectMonthlyProgressReportList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 进度月报-分页查询列表
	 * @param 进度月报，是否调整
	 * @return
	 */
	@ApiOperation(value = "进度月报-分页查询列表", notes = "参数：进度月报，是否调整")
	@PostMapping(value = "/projectMonthlyProgressReportPage/{pageNum}/{pageSize}")
	public ResponseWrapper getProjectMonthlyProgressReportPage(@RequestBody ProjectMonthlyProgressReportQueryVO projectMonthlyProgressReportQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<ProjectMonthlyProgressReportVO> pageInfos = new PageInfo<ProjectMonthlyProgressReportVO>(projectMonthlyProgressReportService.getProjectMonthlyProgressReportPage(projectMonthlyProgressReportQueryVO,pageNum,pageSize));
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 进度月报-新增
	 * @param 进度月报实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/ProjectMonthlyProgressReport")
	@ApiOperation(value = "进度月报-新增", notes = "参数：进度月报对象 model")
	public ResponseWrapper insert(@RequestBody ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO) {
		try{
			if (projectMonthlyProgressReportVO.getJdydYear().intValue() != 4 || projectMonthlyProgressReportVO.getJdydMonth().intValue() > 2) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "月度时间不对，请联系管理员", null);
			}
			ProjectMonthlyProgressReportVO projectMonthlyProgressReport = projectMonthlyProgressReportService.insert(projectMonthlyProgressReportVO);
			if(projectMonthlyProgressReport == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增进度月报失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectMonthlyProgressReport);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 进度月报-更新
	 * @param 进度月报对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/projectMonthlyProgressReport")
	@ApiOperation(value = "进度月报-更新", notes = "参数：进度月报对象 model")
	public ResponseWrapper update(@RequestBody ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO) {
		try{
			if (projectMonthlyProgressReportVO.getYbjzrq() == null){
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "缺少必传参数", null);
			}
			int x = projectMonthlyProgressReportService.update(projectMonthlyProgressReportVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该进度月报不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该进度月报已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 进度月报-查询详情
	 * @param 进度月报ID
	 * @return 状态
	 */
	@GetMapping(value="/projectMonthlyProgressReport/{xmjdybId}")
	@ApiOperation(value = "进度月报-查询详情", notes = "参数：进度月报ID")
	public ResponseWrapper getProjectMonthlyProgressReportInfoById(@PathVariable("xmjdybId") String xmjdybId) {
		try{
			ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = projectMonthlyProgressReportService.getProjectMonthlyProgressReportInfoById(xmjdybId);
			if(projectMonthlyProgressReportVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，进度月报不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectMonthlyProgressReportVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 进度月报-查询详情
	 * @param 进度月报ID
	 * @return 状态
	 */
	@GetMapping(value="/projectMonthlyProgressReportByDate")
	@ApiOperation(value = "进度月报-获取当天截止日期的月报数据", notes = "参数：进度月报ID")
	public ResponseWrapper getProjectMonthlyProgressReportByDate() {
		try{
			ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = projectMonthlyProgressReportService.getProjectMonthlyProgressReportByDate();
			if(projectMonthlyProgressReportVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，进度月报不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectMonthlyProgressReportVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
}
