package com.unis.project.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectProgressBriefingVO;
import com.unis.project.server.service.ProjectProgressBriefingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectProgressBriefingController
 * @ProjectName 项目进度简报 ProjectProgressBriefingController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "项目进度简报 ", tags = "项目进度简报")
@Slf4j
public class ProjectProgressBriefingController {

	@Autowired
	private ProjectProgressBriefingService projectProgressBriefingService;

	/**
	 * @author WangZL
	 * @Description 项目进度简报-新增
	 * @param 项目进度简报实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/projectProgressBriefing")
	@ApiOperation(value = "项目进度简报-新增", notes = "参数：项目进度简报信息对象 model")
	public ResponseWrapper insert(@RequestBody ProjectProgressBriefingVO projectProgressBriefingVO) {
		try{
			if(StringUtils.isEmpty(projectProgressBriefingVO.getXmsqId())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			} else if (StringUtils.isEmpty(projectProgressBriefingVO.getXmjdybId())) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			} else if (projectProgressBriefingVO.getXmjdzt() == null){
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			ProjectProgressBriefingVO projectProgressBriefing = projectProgressBriefingService.insert(projectProgressBriefingVO);
			if(projectProgressBriefing == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增项目进度简报失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectProgressBriefing);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目进度简报-更新
	 * @param 项目进度简报对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/projectProgressBriefing")
	@ApiOperation(value = "项目进度简报-更新", notes = "参数：项目进度简报信息对象 model")
	public ResponseWrapper update(@RequestBody ProjectProgressBriefingVO projectProgressBriefingVO) {
		try{
            if(StringUtils.isEmpty(projectProgressBriefingVO.getXmjdjbId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
			int x = projectProgressBriefingService.update(projectProgressBriefingVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目进度简报信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目进度简报信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目进度简报-查询详情
	 * @param 项目申请id
	 * @return
	 */
	@ApiOperation(value = "项目进度简报-查询详情", notes = "参数：项目申请id")
	@PostMapping(value = "/projectProgressBriefingList/{xmsqId}")
	public ResponseWrapper getProjectMaterialDetailsListById(@PathVariable("xmsqId") String xmsqId){
		try {
			if(StringUtils.isEmpty(xmsqId)) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			List<ProjectProgressBriefingVO> projectProgressBriefingVOList = projectProgressBriefingService.getProjectMaterialDetailsListById(xmsqId);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectProgressBriefingVOList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目进度简报-查询验收前当前月度数据
	 * @param 进度月报id
	 * @return
	 */
	@ApiOperation(value = "项目进度简报-查询验收前当前月度数据", notes = "参数：进度月报id")
	@PostMapping(value = "/projectProgressBriefingListByxmjdybId/{xmjdybId}")
	public ResponseWrapper getProjectMaterialDetailsListByxmjdybId(@PathVariable("xmjdybId") String xmjdybId){
		try {
			if(StringUtils.isEmpty(xmjdybId)) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			List<ProjectProgressBriefingVO> projectProgressBriefingVOList = projectProgressBriefingService.getProjectMaterialDetailsListByxmjdybId(xmjdybId);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectProgressBriefingVOList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目进度简报-查询验收前当前月度数据
	 * @param 进度月报id
	 * @return
	 */
	@ApiOperation(value = "项目进度简报-查询当前月度数据对上报数据", notes = "参数：进度月报id")
	@PostMapping(value = "/projectProgressBriefingListByxmjdzt/{xmjdybId}/{xmjdzt}")
	public ResponseWrapper getProjectMaterialDetailsListByxmjdzt(@PathVariable("xmjdybId") String xmjdybId,@PathVariable("xmjdzt") Integer xmjdzt){
		try {
			if(StringUtils.isEmpty(xmjdybId)) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			} else if (xmjdzt == null){
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
			}
			List<ProjectProgressBriefingVO> projectProgressBriefingVOList = projectProgressBriefingService.getProjectMaterialDetailsListByxmjdzt(xmjdybId,xmjdzt);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectProgressBriefingVOList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目进度简报-获取待上报当天截止时间数据
	 * @return
	 */
	@ApiOperation(value = "项目进度简报-获取待上报当天截止时间数据", notes = "参数：")
	@PostMapping(value = "/projectProgressBriefingIdList")
	public ResponseWrapper getProjectProgressBriefingIdList(){
		try {
			List<String> xmjdjbIdList = projectProgressBriefingService.getProjectProgressBriefingIdList();
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), xmjdjbIdList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}
}
