package com.unis.project.server.controller;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.JsonUtils;
import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectProposalReportVO;
import com.unis.project.common.vo.backlog.BacklogAddVO;
import com.unis.project.server.service.ProjectProposalReportService;
import com.unis.project.server.service.mq.BacklogMQService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/10/28 18:01
 * Version 1.0
 */
@RestController
@Slf4j
@Api(value = "项目管理-项目建议书/可研报告", tags = "项目管理-项目建议书/可研报告")
public class ProjectProposalReportController {

    @Autowired
    private ProjectProposalReportService reportService;
    @Autowired
    private BacklogMQService mqService;


    @ApiOperation(value = "项目建议书/可研报告-新增", notes = "项目建议书/可研报告-新增")
    @PostMapping(value = "/projectProposalReport")
    public ResponseWrapper insertProjectProposalReport(@RequestBody ProjectProposalReportVO proposalReportVO){
        try {
            if(StringUtils.isEmpty(proposalReportVO.getXmsqId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (proposalReportVO.getXmwblx() == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            ProjectProposalReportVO projectProposalReportVO = reportService.insertProjectProposalReport(proposalReportVO);
            if (projectProposalReportVO == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增建议书报告失败，请重新输入", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectProposalReportVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "项目建议书/可研报告-查询详情", notes = "项目建议书/可研报告-查询详情")
    @PostMapping(value = "/projectProposalReportDetail/{xmsqId}/{xmwblx}")
    public ResponseWrapper getProjectProposalReportDetail(@PathVariable("xmsqId") String xmsqId,@PathVariable("xmwblx") Integer xmwblx){
        try {
            if(StringUtils.isEmpty(xmsqId)) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (xmwblx == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            ProjectProposalReportVO reportVO = reportService.getProjectProposalReportDetail(xmsqId,xmwblx);
            if(reportVO == null) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，建议书报告不存在", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), reportVO);
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }

    @ApiOperation(value = "项目建议书/可研报告-更新", notes = "参数：ProjectBidingVO")
    @PutMapping(value = "/projectProposal")
    public ResponseWrapper updateProjectProposalReport(@RequestBody ProjectProposalReportVO ProjectProposalReportVO){
        try {
            if(StringUtils.isEmpty(ProjectProposalReportVO.getXmsqId())) {
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            } else if (ProjectProposalReportVO.getXmwblx() == null){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "有必传参数为空", null);
            }
            int i = reportService.updateProjectProposalReport(ProjectProposalReportVO);
            if (i < 0){
                return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "更新失败", null);
            }
            return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), "更新成功");
        } catch (Exception e) {
            log.error(e.getMessage());
            return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
        }
    }
}
