package com.unis.project.server.controller;

import com.github.pagehelper.PageInfo;
import com.unis.common.utils.ResponseWrapper;
import com.unis.project.common.vo.ProjectTemplateQueryVO;
import com.unis.project.common.vo.ProjectTemplateVO;
import com.unis.project.server.service.ProjectTemplateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectTemplateController
 * @ProjectName 项目模版 ProjectTemplateController
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@RestController
@Api(value = "项目模版 ", tags = "项目模版")
@Slf4j
public class ProjectTemplateController {

	@Autowired
	private ProjectTemplateService projectTemplateService;

	/**
	 * @author WangZL
	 * @Description 项目模版-查询列表
	 * @param 项目模板名称，项目阶段
	 * @return 项目模版列表
	 */
	@ApiOperation(value = "项目模版-查询列表", notes = "参数：项目模板名称，项目阶段")
	@PostMapping(value = "/projectTemplateList")
	public ResponseWrapper getProjectTemplateList(@RequestBody ProjectTemplateQueryVO projectTemplateQueryVO){
		try {
			List<ProjectTemplateVO> projectTemplateList = projectTemplateService.getProjectTemplateList(projectTemplateQueryVO);
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectTemplateList);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目模版-分页查询列表
	 * @param 项目模板名称，项目阶段
	 * @return
	 */
	@ApiOperation(value = "项目模版-分页查询列表", notes = "参数：项目模板名称，项目阶段")
	@PostMapping(value = "/projectTemplatePage/{pageNum}/{pageSize}")
	public ResponseWrapper getProjectTemplatePage(@RequestBody ProjectTemplateQueryVO projectTemplateQueryVO ,@PathVariable("pageNum")Integer pageNum,@PathVariable("pageSize") Integer pageSize) {
		try{
			PageInfo<ProjectTemplateVO> pageInfos = new PageInfo<ProjectTemplateVO>(projectTemplateService.getProjectTemplatePage(projectTemplateQueryVO,pageNum,pageSize));
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), pageInfos);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目模版-新增
	 * @param 项目模版信息实体 models
	 * @return 新增状态
	 */
	@PostMapping(value = "/projectTemplate")
	@ApiOperation(value = "项目模版-新增", notes = "参数：项目模版信息对象 model")
	public ResponseWrapper insert(@RequestBody ProjectTemplateVO projectTemplateVO) {
		try{
			ProjectTemplateVO projectTemplate = projectTemplateService.insert(projectTemplateVO);
			if(projectTemplate == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "新增项目模版失败，请重新输入", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectTemplate);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目模版-更新
	 * @param 项目模版信息对象 model
	 * @return 新增状态
	 */
	@PutMapping(value = "/projectTemplate")
	@ApiOperation(value = "项目模版-更新", notes = "参数：项目模版信息对象 model")
	public ResponseWrapper update(@RequestBody ProjectTemplateVO projectTemplateVO) {
		try{
			int x = projectTemplateService.update(projectTemplateVO);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目模版信息不存在", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "该项目模版信息已被作废，不能进行更新",null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目模版-删除
	 * @param 项目模版ID
	 * @return 状态
	 */
	@DeleteMapping(value="/projectTemplate/{xmmbId}")
	@ApiOperation(value = "项目模版-删除", notes = "参数：项目模版ID")
	public ResponseWrapper delete(@PathVariable("xmmbId") String xmmbId) {
		try{
			int x = projectTemplateService.delete(xmmbId);
			if(x>0) {
				return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(),null);
			} else if (x==0) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败", null);
			} else {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "删除失败,请项目模版ID是否正确", null);
			}
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

	/**
	 * @author WangZL
	 * @Description 项目模版-查询详情
	 * @param 项目模版ID
	 * @return 状态
	 */
	@GetMapping(value="/projectTemplate/{xmmbId}")
	@ApiOperation(value = "项目模版-查询详情", notes = "参数：项目模版ID")
	public ResponseWrapper getProjectTemplateInfoById(@PathVariable("xmmbId") String xmmbId) {
		try{
			ProjectTemplateVO projectTemplateVO = projectTemplateService.getProjectTemplateInfoById(xmmbId);
			if(projectTemplateVO == null) {
				return ResponseWrapper.success(HttpStatus.BAD_REQUEST.value(), "获取失败，项目模版不存在", null);
			}
			return ResponseWrapper.success(HttpStatus.OK.value(), HttpStatus.OK.getReasonPhrase(), projectTemplateVO);
		} catch (Exception e) {
			e.printStackTrace();
			log.error(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(), HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),"服务错误，请联系管理员");
	}

}
