package com.unis.project.server.domain;


import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.vo.FileQueryVO;
import com.unis.project.common.vo.FileVO;
import com.unis.project.server.dao.FileDao;
import com.unis.project.server.entity.FileDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title FileDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class FileDomain extends BaseDomain {

	@Autowired
	private FileDao fileDao;

	/**
	 * 新增文件信息列表
	 * @param fileVOList
	 * @param sjId
	 * @return
	 */
	public void insertFileList(List<FileVO> fileVOList, String sjId) {
		if (fileVOList != null && fileVOList.size() > 0) {
			for (FileVO fileVO : fileVOList) {
				this.insertFile(fileVO,sjId);
			}
		}
	}

	/**
	 * 新增文件信息
	 * @param fileVO
	 * @param sjId
	 * @return
	 */
	public void insertFile(FileVO fileVO,String sjId) {
		FileDO fileDO = new FileDO();
		Integer id = fileDao.selectMaxId();
		if (id == null) {
			id = 0;
		}
		fileVO.setId(id + 1);
		fileVO.setSjId(sjId);
		fileVO.setStatus(1);
		fileVO.setFileStatus(0);
		fileVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(fileVO, fileDO);
		fileDao.insert(fileDO);
	}

	/**
	 * 更新文件信息
	 * @param fileVOList
	 * @param sjId
	 */
	public void updateFileList(List<FileVO> fileVOList,String sjId) {
		if (fileVOList != null) {
			for (FileVO fileVO : fileVOList) {
				FileDO fileDO = fileDao.getFileInfo(fileVO.getId());
				if (fileDO == null) {
					if (fileVO.getFileId() != null) {
						this.insertFile(fileVO, sjId);
					}
				} else {
					LsBeanUtils.copyAllProperties(fileVO, fileDO);
					fileDao.update(fileDO);
				}
			}
		}
	}

	/**
	 * 查询文件列表
	 * @param sjId
	 * @return
	 */
	public List<FileVO> getFileListBySjId(String sjId) {
		List<FileDO> fileDOList = fileDao.getFileListBySjId(sjId);
		List<FileVO> fileVOList = new ArrayList<>();
		if (fileDOList != null) {
			for (FileDO fileDO : fileDOList) {
				FileVO fileVO = new FileVO();
				LsBeanUtils.copyAllProperties(fileDO, fileVO);
				fileVOList.add(fileVO);
			}
		}
		return fileVOList;
	}

	/**
	 * 获取文件列表
	 * @param fileQueryVO
	 * @return
	 */
	public List<FileVO> getFileList(FileQueryVO fileQueryVO) {
		return fileDao.getFileList(fileQueryVO);
	}

	/**
	 * 新增文件信息
	 * @param fileVO
	 * @return
	 */
	public FileVO insert(FileVO fileVO) {
		//数据id  文件FE+20190830+001
		String prefix = "FE"+ DateUtil.getDate();
		String sjId = getMaxCodeById(fileDao.getMaxCodeById(prefix),prefix,3);
		this.insertFile(fileVO,sjId);
		fileVO.setSjId(sjId);
		return fileVO;
	}

	/**
	 * 根据文件ID获取文件信息
	 * @param id
	 * @return
	 */
	public FileVO getFileInfoById(Integer id) {
		FileDO fileDO = fileDao.getFileInfo(id);
		if(fileDO == null) {
			return null;
		}
		FileVO fileVO = new FileVO();
		LsBeanUtils.copyAllProperties(fileDO, fileVO);
		return fileVO;
	}

	/**
	 * 更新文件信息
	 * @param fileVO
	 * @return
	 */
	public int update(FileVO fileVO) {
		FileDO fileDO = fileDao.getFileInfo(fileVO.getId());
		if (fileDO == null) {
			return 0;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(fileVO, fileDO);
		return fileDao.update(fileDO);
	}
}
