package com.unis.project.server.domain;


import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.constant.MaterialStatusConstant;
import com.unis.project.common.vo.ProjectApplicationVO;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.ProjectQueryVO;
import com.unis.project.server.dao.ProjectApplicationDao;
import com.unis.project.server.entity.ProjectApplicationDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectApplicationDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectApplicationDomain extends BaseDomain {

	@Autowired
	private ProjectApplicationDao projectApplicationDao;

	@Autowired
	private ProjectMaterialDetailsDomain projectMaterialDetailsDomain;

	/**
	 * 获取项目申请列表
	 * @param projectQueryVO
	 * @return
	 */
	public List<ProjectApplicationVO> getProjectApplicationList(ProjectQueryVO projectQueryVO) {
		return projectApplicationDao.getProjectApplicationList(projectQueryVO);
	}

	/**
	 * 新增项目申请信息
	 * @param projectApplicationVO
	 * @return
	 */
	public ProjectApplicationVO insert(ProjectApplicationVO projectApplicationVO) {
		ProjectApplicationDO projectApplicationDO = new ProjectApplicationDO();
		//项目申请id  项目id+001
		String xmId = projectApplicationVO.getXmId();
		String xmsqId = getMaxCodeById(projectApplicationDao.getMaxCodeById(xmId),xmId,3);
		projectApplicationVO.setXmsqId(xmsqId);
		projectApplicationVO.setXmId(xmId);
		projectApplicationVO.setStatus(1);
		projectApplicationVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(projectApplicationVO, projectApplicationDO);
		projectMaterialDetailsDomain.insertProjectMaterialDetailsList(projectApplicationVO.getXmsqclList(),xmsqId);
		projectApplicationDao.insert(projectApplicationDO);
		return projectApplicationVO;
	}

	/**
	 * 根据项目申请ID获取项目申请信息
	 * @param xmsqId
	 * @return
	 */
	public ProjectApplicationVO getProjectApplicationInfoById(String xmsqId) {
		ProjectApplicationVO projectApplicationVO = projectApplicationDao.getProjectApplicationInfo(xmsqId);
		if(projectApplicationVO == null) {
			return null;
		}
		projectApplicationVO.setXmsqtjList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(projectApplicationVO.getXmId(), MaterialStatusConstant.SQTJ,null,null)));
		projectApplicationVO.setXmsqclList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmsqId,MaterialStatusConstant.SQCL,null,null)));
		return projectApplicationVO;
	}

	/**
	 * 更新项目申请信息
	 * @param projectApplicationVO
	 * @return
	 */
	public int update(ProjectApplicationVO projectApplicationVO) {
		ProjectApplicationVO projectApplicationInfo = projectApplicationDao.getProjectApplicationInfo(projectApplicationVO.getXmsqId());
		if (projectApplicationInfo == null) {
			return 0;
		}
		ProjectApplicationDO projectApplicationDO = new ProjectApplicationDO();
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectApplicationVO, projectApplicationDO);
		projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectApplicationVO.getXmsqclList(),projectApplicationVO.getXmsqId());
		return projectApplicationDao.update(projectApplicationDO);
	}

	/**
	 * 获取资金申请提交后和验收申请提交前数据
	 * @return
	 */
	public List<String> getProjectApplicationIdList() {
		return projectApplicationDao.getProjectApplicationIdList();
	}

	/**
	 * 获取当天截止时间的项目申请id
	 * @return
	 */
	public List<String> getProjectInfoDate() {
		return projectApplicationDao.getProjectInfoDate();
	}
}
