package com.unis.project.server.domain;


import com.alibaba.fastjson.JSON;
import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.constant.MaterialStatusConstant;
import com.unis.project.common.constant.ProjectStatusConstant;
import com.unis.project.common.vo.ProjectApplicationVO;
import com.unis.project.common.vo.ProjectApprovalAcceptanceVO;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.backlog.BacklogAddVO;
import com.unis.project.common.vo.backlog.BacklogUpdateVO;
import com.unis.project.common.vo.backlog.JsonUtils;
import com.unis.project.common.vo.backlog.ReceiverCollectionVO;
import com.unis.project.server.dao.ProjectApplicationDao;
import com.unis.project.server.dao.ProjectApprovalAcceptanceDao;
import com.unis.project.server.entity.ProjectApprovalAcceptanceDO;
import com.unis.project.server.service.mq.BacklogMQService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectApprovalAcceptanceDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectApprovalAcceptanceDomain extends BaseDomain {

	@Autowired
	private ProjectApprovalAcceptanceDao projectApprovalAcceptanceDao;
	@Autowired
	private BacklogMQService mqService;
	@Autowired
	private ProjectApplicationDao projectApplicationDao;
	@Autowired
	private ProjectMaterialDetailsDomain projectMaterialDetailsDomain;

	private static final Integer PROJECT_APPROVAL = 1;//项目立项类型：立项审批
	private static final Integer PROJECT_ACCEPTANCE = 2;//项目立项类型：项目验收

	/**
	 * 新增项目立项验收信息
	 * @param projectApprovalAcceptanceVO
	 * @return
	 */
	public ProjectApprovalAcceptanceVO insert(ProjectApprovalAcceptanceVO projectApprovalAcceptanceVO) {
		ProjectApprovalAcceptanceDO projectApprovalAcceptanceDO = projectApprovalAcceptanceDao.getProjectApprovalAcceptanceInfo(projectApprovalAcceptanceVO);
		if (projectApprovalAcceptanceDO == null) {
			projectApprovalAcceptanceDO = new ProjectApprovalAcceptanceDO();
			String xmsqId = projectApprovalAcceptanceVO.getXmsqId();
			Integer xmlxlx = projectApprovalAcceptanceVO.getXmlxlx();
			String prefix = "";
			String xmlxysId = "";
			Integer[] xmlxlxs = {PROJECT_APPROVAL, PROJECT_ACCEPTANCE};
			String[] lxs = {"SP", "YS"};
			int index = 0;
			while (index < xmlxlxs.length) {
				if (xmlxlxs[index].equals(xmlxlx)) {
					prefix = xmsqId + lxs[index]; // 项目申请id  项目审批说明id 项目id+SP+001,项目验收申请id 项目id+YS+001
					xmlxysId = getMaxCodeById(projectApprovalAcceptanceDao.getMaxCodeById(prefix), prefix, 3);
				}
				index++;
			}
			projectApprovalAcceptanceVO.setXmlxysId(xmlxysId);
			projectApprovalAcceptanceVO.setXmsqId(xmsqId);
			projectApprovalAcceptanceVO.setStatus(1);
			projectApprovalAcceptanceVO.setCreateDate(new Date());
			LsBeanUtils.copyAllProperties(projectApprovalAcceptanceVO, projectApprovalAcceptanceDO);
			projectMaterialDetailsDomain.insertProjectMaterialDetailsList(projectApprovalAcceptanceVO.getXmlxysList(), xmlxysId);
			int num = projectApprovalAcceptanceDao.insertSelective(projectApprovalAcceptanceDO);
			ProjectApplicationVO applicationVO = projectApplicationDao.getProjectApplicationInfo(projectApprovalAcceptanceVO
					.getXmsqId());
			if(num>0&&(ProjectStatusConstant.ACCEPTANCE_APPLICATION.getValue().equals(applicationVO.getXmzbzt()))){
				//======================张新亮 添加代办 start========================
				System.out.println("*************进入创建待办************");
				BacklogAddVO record=new BacklogAddVO();
				record.buildAddVO(record);
				record.setSubmitter(projectApprovalAcceptanceVO.getSubmitter());
				record.setSubmitterId(projectApprovalAcceptanceVO.getSubmitterId());
				record.setCompanyName(projectApprovalAcceptanceVO.getCompanyName());
				record.setItemQuery(projectApprovalAcceptanceVO.getItemQuery());
				record.setItemId(projectApprovalAcceptanceVO.getXmlxysId());
				record.setItemName(projectApprovalAcceptanceVO.getItemName());
				record.setItemQueryHaveDone(projectApprovalAcceptanceVO.getItemQueryHaveDone());
				record.setItemUrlHaveDone(projectApprovalAcceptanceVO.getItemUrlHaveDone());
				record.setItemUrl(projectApprovalAcceptanceVO.getUrl());
				record.setItemStatus(Integer.valueOf(ProjectStatusConstant.ACCEPTANCE_APPLICATION.getValue()));
				record.setItemStatusName(ProjectStatusConstant.ACCEPTANCE_APPLICATION.getName());
				// 另起线程执行待办
				new Thread(new Runnable() {
					@Override
					public void run() {
						if(projectApprovalAcceptanceVO.getUserList()!=null&&projectApprovalAcceptanceVO.getUserList().size()>0){
							for (ReceiverCollectionVO userVO : projectApprovalAcceptanceVO.getUserList()) {
								System.out.println("********************接收人*******************");
								System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
								System.out.println("********************************************");
								record.setReceiver(userVO.getUserName());
								record.setReceiverId(userVO.getUserId());
								// 需要将对象序列化成JSONObject
								mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
							}
						}
					}
				}).start();
				//======================张新亮 添加代办 end========================
			}
		} else {
		    projectApprovalAcceptanceVO.setXmlxysId(projectApprovalAcceptanceDO.getXmlxysId());
			this.update(projectApprovalAcceptanceVO);
		}
		return projectApprovalAcceptanceVO;
	}

	/**
	 * 根据项目申请ID和立项类型获取项目立项验收信息
	 * @param xmsqId
	 * @param xmlxlx
	 * @return
	 */
	public ProjectApprovalAcceptanceVO getProjectApprovalAcceptanceInfoById(String xmsqId,Integer xmlxlx) {
		ProjectApprovalAcceptanceVO projectApprovalAcceptanceVO = new ProjectApprovalAcceptanceVO();
		projectApprovalAcceptanceVO.setXmsqId(xmsqId);
		projectApprovalAcceptanceVO.setXmlxlx(xmlxlx);
		ProjectApprovalAcceptanceDO projectApprovalAcceptanceDO = projectApprovalAcceptanceDao.getProjectApprovalAcceptanceInfo(projectApprovalAcceptanceVO);
		if(projectApprovalAcceptanceDO == null) {
			return null;
		}
		String xmlxysId = projectApprovalAcceptanceDO.getXmlxysId();
		LsBeanUtils.copyAllProperties(projectApprovalAcceptanceDO, projectApprovalAcceptanceVO);
		if (xmlxlx.equals(PROJECT_APPROVAL)){
		    projectApprovalAcceptanceVO.setXmlxysList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmlxysId, MaterialStatusConstant.LXSP,null,null)));
        } else if (xmlxlx.equals(PROJECT_ACCEPTANCE)){
		    projectApprovalAcceptanceVO.setXmlxysList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmlxysId, MaterialStatusConstant.XMYS,null,null)));
		    projectApprovalAcceptanceVO.setXmysshList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmlxysId, MaterialStatusConstant.YSSH,null,null)));
        }
		return projectApprovalAcceptanceVO;
	}

	/**
	 * 更新项目立项验收信息
	 * @param projectApprovalAcceptanceVO
	 * @return
	 */
	public int update(ProjectApprovalAcceptanceVO projectApprovalAcceptanceVO) {
		String xmlxysId = projectApprovalAcceptanceVO.getXmlxysId();
		ProjectApprovalAcceptanceDO projectApprovalAcceptanceDO = projectApprovalAcceptanceDao.getProjectApprovalAcceptanceInfo(projectApprovalAcceptanceVO);
		if (projectApprovalAcceptanceDO == null) {
			return 0;
		}
		projectApprovalAcceptanceDO = new ProjectApprovalAcceptanceDO();
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectApprovalAcceptanceVO, projectApprovalAcceptanceDO);
		projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectApprovalAcceptanceVO.getXmlxysList(),xmlxysId);
		projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectApprovalAcceptanceVO.getXmysshList(),xmlxysId);
		int num = projectApprovalAcceptanceDao.update(projectApprovalAcceptanceDO);
		ProjectApplicationVO applicationVO = projectApplicationDao.getProjectApplicationInfo(projectApprovalAcceptanceVO
				.getXmsqId());
		if(num>0&&(ProjectStatusConstant.ACCEPTANCE_APPLICATION.getValue().equals(applicationVO.getXmlxzt()))){
			//======================张新亮 添加代办 start========================
			System.out.println("*************进入创建待办************");
			BacklogAddVO record=new BacklogAddVO();
			record.buildAddVO(record);
			record.setSubmitter(projectApprovalAcceptanceVO.getSubmitter());
			record.setSubmitterId(projectApprovalAcceptanceVO.getSubmitterId());
			record.setCompanyName(projectApprovalAcceptanceVO.getCompanyName());
			record.setItemQuery(projectApprovalAcceptanceVO.getItemQuery());
			record.setItemId(projectApprovalAcceptanceVO.getXmlxysId());
			record.setItemName(projectApprovalAcceptanceVO.getItemName());
			record.setItemQueryHaveDone(projectApprovalAcceptanceVO.getItemQueryHaveDone());
			record.setItemUrlHaveDone(projectApprovalAcceptanceVO.getItemUrlHaveDone());
			record.setItemUrl(projectApprovalAcceptanceVO.getUrl());
			record.setItemStatus(Integer.valueOf(ProjectStatusConstant.ACCEPTANCE_APPLICATION.getValue()));
			record.setItemStatusName(ProjectStatusConstant.ACCEPTANCE_APPLICATION.getName());
			// 另起线程执行待办
			new Thread(new Runnable() {
				@Override
				public void run() {
					if(projectApprovalAcceptanceVO.getUserList()!=null&&projectApprovalAcceptanceVO.getUserList().size()>0){
						for (ReceiverCollectionVO userVO : projectApprovalAcceptanceVO.getUserList()) {
							System.out.println("********************接收人*******************");
							System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
							System.out.println("********************************************");
							record.setReceiver(userVO.getUserName());
							record.setReceiverId(userVO.getUserId());
							// 需要将对象序列化成JSONObject
							mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
						}
					}
				}
			}).start();
			//======================张新亮 添加代办 end========================
		}
		if(num>0&& ProjectStatusConstant.ACCEPTANCE.getValue().equals(applicationVO.getXmlxzt())||ProjectStatusConstant.PROJECT_PROGRESS.getValue().equals(applicationVO.getXmlxzt())){
			if(projectApprovalAcceptanceVO.getPsjgzt()!=null){
				BacklogUpdateVO updateVO = new BacklogUpdateVO();
				updateVO.buildUpdateVO(updateVO);
				updateVO.setHandler(projectApprovalAcceptanceVO.getRefresher());
				updateVO.setHandlerId(projectApprovalAcceptanceVO.getRefresherCode());
				updateVO.setItemId(projectApprovalAcceptanceVO.getXmlxysId());
				updateVO.setItemName("项目验收申请为（" +projectApprovalAcceptanceVO.getXmsqspys()+"）的申请已经审核");
				updateVO.setItemStatus(Integer.valueOf(projectApprovalAcceptanceVO.getPsjgzt()));
				if(ProjectStatusConstant.ACCEPTANCE.getValue().equals(applicationVO.getXmlxzt())){
					updateVO.setItemStatusName("通过");
				}else {
					updateVO.setItemStatusName("驳回");
				}
				mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");

			}
		}
		return num;
	}
}
