package com.unis.project.server.domain;

import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.vo.ProjectBidingVO;
import com.unis.project.server.dao.ProjectBidingDao;
import com.unis.project.server.entity.ProjectBidingDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/10/25 17:37
 * Version 1.0
 */

@Component
public class ProjectBiddingDomain extends BaseDomain{

    @Autowired
    private ProjectBidingDao projectBidingDao;

    @Autowired
    private ProjectMaterialDetailsDomain projectMaterialDetailsDomain;

    //项目招标类型：1、设计招标。2、监理招标。3、建设招标
    private static final Integer[] xmlxlxList = {1,2,3};
    private static final String[] xmlxlxNameList = {"SJ","JL","JS"};

    /**
     * 招标信息-查询详情
     * @author 邹杰利
     * @param xmsqId
     * @param xmzblx
     * @return
     */
    public ProjectBidingVO getProjectBiddingDetail(String xmsqId, Integer xmzblx) {
        ProjectBidingVO projectBidingVO = new ProjectBidingVO();
        projectBidingVO.setXmsqId(xmsqId);
        projectBidingVO.setXmzblx(xmzblx);
        ProjectBidingDO projectBidingDO = projectBidingDao.getProjectBidingInfo(projectBidingVO);
        if (projectBidingDO == null){
            return null;
        }
        LsBeanUtils.copyAllProperties(projectBidingDO, projectBidingVO);
        projectBidingVO.setXmzbqkList(projectMaterialDetailsDomain.getProjectMaterialDetailsListBySjId(projectBidingDO.getXmzbId()));
        return projectBidingVO;
    }

    /**
     * 招标信息-新增
     * @author 邹杰利
     * @param projectBidingVO
     * @return
     */
    public ProjectBidingVO insertProjectBidding(ProjectBidingVO projectBidingVO) {
        ProjectBidingDO projectBidingDO = projectBidingDao.getProjectBidingInfo(projectBidingVO);
        if (projectBidingDO == null) {
            projectBidingDO = new ProjectBidingDO();
            String xmsqId = projectBidingVO.getXmsqId();
            Integer xmzblx = projectBidingVO.getXmzblx();
            String prefix = "";
            String xmzbId = "";
            int index = 0;
            while (index < xmlxlxList.length) {
                if (xmlxlxList[index].equals(xmzblx)) {
                    prefix = xmsqId + xmlxlxNameList[index]; // 项目招标id  项目申请id+xmlxlxNameList[index]+001
                    xmzbId = getMaxCodeById(projectBidingDao.getMaxCodeById(prefix), prefix, 3);
                }
                index++;
            }
            projectBidingVO.setXmzbId(xmzbId);
            projectBidingVO.setXmsqId(xmsqId);
            projectBidingVO.setStatus(1);
            projectBidingVO.setCreateDate(new Date());
            LsBeanUtils.copyAllProperties(projectBidingVO, projectBidingDO);
            projectMaterialDetailsDomain.insertProjectMaterialDetailsList(projectBidingVO.getXmzbqkList(), xmzbId);
            projectBidingDao.insertSelective(projectBidingDO);
        } else {
            projectBidingVO.setXmzbId(projectBidingDO.getXmzbId());
            this.update(projectBidingVO);
        }
        return projectBidingVO;
    }

    /**
     * 招标信息-更新
     * @author 邹杰利
     * @param projectBidingVO
     * @return
     */
    public int update(ProjectBidingVO projectBidingVO) {
        String xmzbId = projectBidingVO.getXmzbId();
        ProjectBidingDO projectBidingDO = projectBidingDao.getProjectBidingInfo(projectBidingVO);
        if (projectBidingDO == null) {
            return 0;
        }
        projectBidingDO = new ProjectBidingDO();
        LsBeanUtils.copyAllProperties(projectBidingVO,projectBidingDO);
        projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectBidingVO.getXmzbqkList(),xmzbId);
        return projectBidingDao.update(projectBidingDO);
    }
}
