package com.unis.project.server.domain;


import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.constant.MaterialStatusConstant;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.ProjectQueryVO;
import com.unis.project.common.vo.ProjectVO;
import com.unis.project.server.dao.ProjectDao;
import com.unis.project.server.entity.ProjectDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectDomain extends BaseDomain {

	@Autowired
	private ProjectDao projectDao;

	@Autowired
	private ProjectMaterialDetailsDomain projectMaterialDetailsDomain;


	/**
	 * 获取项目列表
	 * @param projectQueryVO
	 * @return
	 */
	public List<ProjectVO> getProjectList(ProjectQueryVO projectQueryVO) {
		return projectDao.getProjectList(projectQueryVO);
	}

	/**
	 * 新增项目信息
	 * @param projectVO
	 * @return
	 */
	public ProjectVO insert(ProjectVO projectVO) {
		//项目id  项目 XM+20191021+001
		String prefix = "XM"+ DateUtil.getDate();
		String xmId = getMaxCodeById(projectDao.getMaxCodeById(prefix),prefix,3);
		projectVO.setXmId(xmId);
		projectVO.setStatus(1);
		projectVO.setCreateDate(new Date());
		projectVO.setXmjzsj(this.infoDate(projectVO.getXmjzsj()));
		ProjectDO projectDO = new ProjectDO();
		LsBeanUtils.copyAllProperties(projectVO, projectDO);
		projectDao.insertSelective(projectDO);
		projectMaterialDetailsDomain.insertProjectMaterialDetailsList(projectVO.getXmsqtjList(),xmId);
		return projectVO;
	}

	/**
	 * 根据项目ID获取项目信息
	 * @param xmId
	 * @return
	 */
	public ProjectVO getProjectInfoById(String xmId) {
		ProjectDO projectDO = projectDao.getProjectInfo(xmId);
		if(projectDO == null) {
			return null;
		}
		ProjectVO projectVO = new ProjectVO();
		LsBeanUtils.copyAllProperties(projectDO, projectVO);
		projectVO.setXmsqtjList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmId, MaterialStatusConstant.SQTJ,null,null)));
		return projectVO;
	}

	/**
	 * 更新项目信息
	 * @param projectVO
	 * @return
	 */
	public int update(ProjectVO projectVO) {
		ProjectDO projectDO = projectDao.getProjectInfo(projectVO.getXmId());
		if (projectDO == null) {
			return 0;
		}
		projectVO.setXmjzsj(this.infoDate(projectVO.getXmjzsj()));
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectVO, projectDO);
		projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectVO.getXmsqtjList(),projectVO.getXmId());
		return projectDao.updateByPrimaryKey(projectDO);
	}

	/**
	 * 获取已发布最新项目信息
	 * @return
	 */
	public ProjectVO getProjectInfo() {
		ProjectDO projectDO = projectDao.getProject();
		if(projectDO == null) {
			return null;
		}
		ProjectVO projectVO = new ProjectVO();
		LsBeanUtils.copyAllProperties(projectDO, projectVO);
		projectVO.setXmsqtjList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(projectDO.getXmId(), MaterialStatusConstant.SQTJ,null,null)));
		return projectVO;
	}

	/**
	 * 截止时间为xxxx-xx-xx 23:23:59
	 * @param date
	 * @return
	 */
	public Date infoDate(Date date){
		date = DateUtil.turnStrDateToJavaUtilDate(DateUtil.getDateFormat(date,"yyyy-MM-dd")+" 23:23:59","yyyy-MM-dd hh:mm:ss");
		return date;
	}

}
