package com.unis.project.server.domain;

import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.constant.MaterialStatusConstant;
import com.unis.project.common.vo.ProjectFundApplicationVO;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.server.dao.ProjectFundApplicationDao;
import com.unis.project.server.entity.ProjectFundApplicationDO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/10/25 17:37
 * Version 1.0
 */

@Component
public class ProjectFundApplicationDomain extends BaseDomain{

    @Autowired
    private ProjectFundApplicationDao projectFundApplicationDao;

    @Autowired
    private ProjectMaterialDetailsDomain projectMaterialDetailsDomain;

    /**
     * 资金申请-新增
     * @param projectFundApplicationVO
     * @return
     */
    public int insert(ProjectFundApplicationVO projectFundApplicationVO) {
        ProjectFundApplicationDO projectFundApplicationDO = new ProjectFundApplicationDO();
        String xmsqId = projectFundApplicationVO.getXmsqId();
        String xmzjsqId = getMaxCodeById(projectFundApplicationDao.getMaxCodeById(xmsqId),xmsqId,3);
        projectFundApplicationVO.setXmzjsqId(xmzjsqId);
        projectFundApplicationVO.setStatus(1);
        projectFundApplicationVO.setCreateDate(new Date());
        LsBeanUtils.copyAllProperties(projectFundApplicationVO, projectFundApplicationDO);
        projectMaterialDetailsDomain.insertProjectMaterialDetailsList(projectFundApplicationVO.getXmzjsqList(),xmzjsqId);
        return projectFundApplicationDao.insertSelective(projectFundApplicationDO);
    }

    /**
     * 资金申请-更新
     * @param projectFundApplicationVO
     * @return
     */
    public int update(ProjectFundApplicationVO projectFundApplicationVO) {
        String xmzjsqId = projectFundApplicationVO.getXmzjsqId();
        ProjectFundApplicationDO projectFundApplicationDO = projectFundApplicationDao.getProjectFundApplicationInfo(xmzjsqId);
        if (projectFundApplicationDO == null) {
            return 0;
        }
        projectFundApplicationDO = new ProjectFundApplicationDO();
        //进行传递参数copy
        LsBeanUtils.copyAllProperties(projectFundApplicationVO, projectFundApplicationDO);
        projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectFundApplicationVO.getXmzjsqList(),xmzjsqId);
        return projectFundApplicationDao.update(projectFundApplicationDO);
    }

    /**
     * 资金申请-查询详情
     * @param xmsqId
     * @return
     */
    public List<ProjectFundApplicationVO> getProjectFundApplicationInfoById(String xmsqId) {
        List<ProjectFundApplicationDO> projectFundApplicationDOList = projectFundApplicationDao.getProjectFundApplication(xmsqId);
        List<ProjectFundApplicationVO> projectFundApplicationVOList = new ArrayList<>();
        if (projectFundApplicationDOList != null && projectFundApplicationDOList.size() > 0){
            for (ProjectFundApplicationDO projectFundApplicationDO : projectFundApplicationDOList) {
                ProjectFundApplicationVO projectFundApplicationVO = new ProjectFundApplicationVO();
                LsBeanUtils.copyAllProperties(projectFundApplicationDO, projectFundApplicationVO);
                projectFundApplicationVO.setXmzjsqList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(projectFundApplicationDO.getXmzjsqId(), MaterialStatusConstant.ZJSQ,null,null)));
                projectFundApplicationVOList.add(projectFundApplicationVO);
            }
        }
        return projectFundApplicationVOList;
    }

    /**
     *
     * @param projectFundApplicationVOList
     * @return
     */
    public List<ProjectFundApplicationVO> insertProjectFundApplicationList(List<ProjectFundApplicationVO> projectFundApplicationVOList) {
        if (projectFundApplicationVOList != null && projectFundApplicationVOList.size() > 0){
            for (ProjectFundApplicationVO projectFundApplicationVO : projectFundApplicationVOList) {
                if (StringUtils.isEmpty(projectFundApplicationVO.getXmsqId())) {
                    return null;
                } else if (projectFundApplicationVO.getSfecss() == null){
                    return null;
                }
                this.insert(projectFundApplicationVO);
            }
        }
        return projectFundApplicationVOList;
    }

    /**
     *
     * @param projectFundApplicationVOList
     * @return
     */
    public int updateProjectFundApplicationList(List<ProjectFundApplicationVO> projectFundApplicationVOList) {
        int x = 0;
        if (projectFundApplicationVOList != null && projectFundApplicationVOList.size() > 0){
            for (ProjectFundApplicationVO projectFundApplicationVO : projectFundApplicationVOList) {
                if (StringUtils.isEmpty(projectFundApplicationVO.getXmsqId())) {
                    return 0;
                } else if (projectFundApplicationVO.getSfecss() == null){
                    return 0;
                }
                if (StringUtils.isEmpty((projectFundApplicationVO.getXmzjsqId()))){
                    x = this.insert(projectFundApplicationVO);
                } else {
                    x = this.update(projectFundApplicationVO);
                }
            }
        }
        return x;
    }
}
