package com.unis.project.server.domain;


import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.vo.FileVO;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.ProjectMaterialDetailsVO;
import com.unis.project.server.dao.FileDao;
import com.unis.project.server.dao.ProjectMaterialDetailsDao;
import com.unis.project.server.entity.ProjectMaterialDetailsDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectMaterialDetailsDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectMaterialDetailsDomain extends BaseDomain {

	@Autowired
	private ProjectMaterialDetailsDao projectMaterialDetailsDao;

	@Autowired
	private FileDomain fileDomain;

	@Autowired
	private FileDao fileDao;

	//项目材料类型：1、项目申请条件。2、项目申请材料。3、设计招标附件。4、项目建议书附件。5、可研报告附件。6、可研报告审核附件。7、立项审批附件。
	// 8、监理招标附件。9、建设招标附件。10、资金申请附件。11、项目验收附件。12、项目验收审核附件。13、项目补充材料附件。14、项目建议书审核附件
	private static final Integer[] xmcllxList = {1,2,3,4,5,6,7,8,9,10,11,12,13,14};
	private static final String[] xmcllxNameList = {"SQTJ","SQCL","SJZB","XMJYS","KYBG","BGSH","LXSP","JLZB","JSZB","ZJSQ","XMYS","YSSH","BCCL","JYSSH"};
	private static final Integer PROJECT_ACCEPTANCE = 3;//项目材料类型：项目验收材料

	/**
	 * 新增项目材料信息列表
	 * @param projectMaterialDetailsVOList
	 * @param sjId
	 * @return
	 */
	public List<ProjectMaterialDetailsVO> insertProjectMaterialDetailsList(List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList, String sjId) {
		if (projectMaterialDetailsVOList != null && projectMaterialDetailsVOList.size() > 0) {
			for (ProjectMaterialDetailsVO projectMaterialDetailsVO : projectMaterialDetailsVOList) {
				this.insertProjectMaterialDetails(projectMaterialDetailsVO,sjId);
			}
		}
		return projectMaterialDetailsVOList;
	}

	/**
	 * 新增项目材料信息
	 * @param projectMaterialDetailsVO
	 * @param sjId
	 * @return
	 */
	public int insertProjectMaterialDetails(ProjectMaterialDetailsVO projectMaterialDetailsVO,String sjId) {
		ProjectMaterialDetailsDO projectMaterialDetailsDO = new ProjectMaterialDetailsDO();
		Integer xmcllx = projectMaterialDetailsVO.getXmcllx();
		String prefix = "";
		String xmclxqId = "";
		int index=0;
		while (index < xmcllxList.length){
			if (xmcllxList[index].equals(xmcllx)){
				prefix = sjId + xmcllxNameList[index]; // 项目材料id  数据id+xmcllxNameList[index]+001
				xmclxqId = getMaxCodeById(projectMaterialDetailsDao.getMaxCodeById(prefix),prefix,3);
			}
			index ++;
		}
		projectMaterialDetailsVO.setXmclxqId(xmclxqId);
		projectMaterialDetailsVO.setSjId(sjId);
		projectMaterialDetailsVO.setStatus(1);
		projectMaterialDetailsVO.setIsdelete(0);
		projectMaterialDetailsVO.setCreateDate(new Date());
		LsBeanUtils.copyAllProperties(projectMaterialDetailsVO, projectMaterialDetailsDO);
		fileDomain.insertFileList(projectMaterialDetailsVO.getXmclFileList(),xmclxqId);
		// 为上传附件指定业务id
		List<FileVO> fileVOList = projectMaterialDetailsVO.getXmclFileList();
		fileVOList.stream().forEach(file->{
			fileDao.updateSysFileBusinessId(sjId,projectMaterialDetailsVO.getStatus(),file.getFileId());
		});
		return projectMaterialDetailsDao.insert(projectMaterialDetailsDO);
	}

	/**
	 * 更新项目材料信息
	 * @param projectMaterialDetailsVOList
	 * @param sjId
	 */
	public int updateProjectMaterialDetailsList(List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList,String sjId) {
		int x = 0;
		if (projectMaterialDetailsVOList != null) {
			for (ProjectMaterialDetailsVO projectMaterialDetailsVO : projectMaterialDetailsVOList) {
				ProjectMaterialDetailsDO projectMaterialDetailsDO = projectMaterialDetailsDao.getProjectMaterialDetailsInfo(projectMaterialDetailsVO.getXmclxqId());
				if (projectMaterialDetailsDO == null) {
					if (projectMaterialDetailsVO.getXmcllx() != null) {
						x = this.insertProjectMaterialDetails(projectMaterialDetailsVO, sjId);
					} else {
						return 0;
					}
				} else {
					LsBeanUtils.copyAllProperties(projectMaterialDetailsVO, projectMaterialDetailsDO);
					fileDomain.updateFileList(projectMaterialDetailsVO.getXmclFileList(),projectMaterialDetailsVO.getXmclxqId());
					x = projectMaterialDetailsDao.update(projectMaterialDetailsDO);
					// 为上传附件指定业务id
					List<FileVO> fileVOList = projectMaterialDetailsVO.getXmclFileList();
					fileVOList.stream().forEach(file->{
						fileDao.updateSysFileBusinessId(sjId,projectMaterialDetailsVO.getStatus(),file.getFileId());
					});
				}
			}
		}
		return x;
	}

	/**
	 * 查询项目材料列表
	 * @param sjId
	 * @return
	 */
	public List<ProjectMaterialDetailsVO> getProjectMaterialDetailsListBySjId(String sjId) {
		List<ProjectMaterialDetailsDO> projectMaterialDetailsDOList = projectMaterialDetailsDao.getProjectMaterialDetailsListBySjId(sjId);
		List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList = new ArrayList<>();
		if (projectMaterialDetailsDOList != null && projectMaterialDetailsDOList.size() > 0) {
			for (ProjectMaterialDetailsDO projectMaterialDetailsDO : projectMaterialDetailsDOList) {
				ProjectMaterialDetailsVO projectMaterialDetailsVO = new ProjectMaterialDetailsVO();
				LsBeanUtils.copyAllProperties(projectMaterialDetailsDO, projectMaterialDetailsVO);
				projectMaterialDetailsVO.setXmclFileList(fileDomain.getFileListBySjId(projectMaterialDetailsDO.getXmclxqId()));
				projectMaterialDetailsVOList.add(projectMaterialDetailsVO);
			}
		}
		return projectMaterialDetailsVOList;
	}

	/**
	 * 根据项目材料ID获取项目材料信息
	 * @param xmclxqId
	 * @return
	 */
	public ProjectMaterialDetailsVO getProjectMaterialDetailsInfoById(String xmclxqId) {
		ProjectMaterialDetailsDO projectMaterialDetailsDO = projectMaterialDetailsDao.getProjectMaterialDetailsInfo(xmclxqId);
		if(projectMaterialDetailsDO == null) {
			return null;
		}
		ProjectMaterialDetailsVO projectMaterialDetailsVO = new ProjectMaterialDetailsVO();
		LsBeanUtils.copyAllProperties(projectMaterialDetailsDO, projectMaterialDetailsVO);
		projectMaterialDetailsVO.setXmclFileList(fileDomain.getFileListBySjId(projectMaterialDetailsDO.getXmclxqId()));
		return projectMaterialDetailsVO;
	}

	/**
	 * 更新项目材料信息
	 * @param projectMaterialDetailsVO
	 * @return
	 */
	public int update(ProjectMaterialDetailsVO projectMaterialDetailsVO) {
		ProjectMaterialDetailsDO projectMaterialDetailsDO = projectMaterialDetailsDao.getProjectMaterialDetailsInfo(projectMaterialDetailsVO.getXmclxqId());
		if (projectMaterialDetailsDO == null) {
			return 0;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectMaterialDetailsVO, projectMaterialDetailsDO);
		fileDomain.updateFileList(projectMaterialDetailsVO.getXmclFileList(),projectMaterialDetailsVO.getXmclxqId());
		return projectMaterialDetailsDao.update(projectMaterialDetailsDO);
	}

    /**
     * 项目材料-查看补充材料列表
     * @param projectMaterialDetailsQueryVO
     * @return
     */
    public List<ProjectMaterialDetailsVO> getProjectMaterialDetailsList(ProjectMaterialDetailsQueryVO projectMaterialDetailsQueryVO) {
        List<ProjectMaterialDetailsDO> projectMaterialDetailsDOList = projectMaterialDetailsDao.getProjectMaterialDetailsList(projectMaterialDetailsQueryVO);
        List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList = new ArrayList<>();
        if (projectMaterialDetailsDOList != null && projectMaterialDetailsDOList.size() > 0) {
            for (ProjectMaterialDetailsDO projectMaterialDetailsDO : projectMaterialDetailsDOList) {
                ProjectMaterialDetailsVO projectMaterialDetailsVO = new ProjectMaterialDetailsVO();
                LsBeanUtils.copyAllProperties(projectMaterialDetailsDO, projectMaterialDetailsVO);
                projectMaterialDetailsVO.setXmclFileList(fileDomain.getFileListBySjId(projectMaterialDetailsDO.getXmclxqId()));
                projectMaterialDetailsVOList.add(projectMaterialDetailsVO);
            }
        }
        return projectMaterialDetailsVOList;
    }

    /**
     * 查看删除数据
     * @param projectMaterialDetailsQueryVO
     * @return
     */
    public List<ProjectMaterialDetailsVO> getProjectMaterialDetailsDeleteList(ProjectMaterialDetailsQueryVO projectMaterialDetailsQueryVO) {
        List<ProjectMaterialDetailsDO> projectMaterialDetailsDOList = projectMaterialDetailsDao.getProjectMaterialDetailsDeleteList(projectMaterialDetailsQueryVO);
        List<ProjectMaterialDetailsVO> projectMaterialDetailsVOList = new ArrayList<>();
        if (projectMaterialDetailsDOList != null && projectMaterialDetailsDOList.size() > 0) {
            for (ProjectMaterialDetailsDO projectMaterialDetailsDO : projectMaterialDetailsDOList) {
                ProjectMaterialDetailsVO projectMaterialDetailsVO = new ProjectMaterialDetailsVO();
                LsBeanUtils.copyAllProperties(projectMaterialDetailsDO, projectMaterialDetailsVO);
                projectMaterialDetailsVO.setXmclFileList(fileDomain.getFileListBySjId(projectMaterialDetailsDO.getXmclxqId()));
                projectMaterialDetailsVOList.add(projectMaterialDetailsVO);
            }
        }
        return projectMaterialDetailsVOList;
    }
}
