package com.unis.project.server.domain;


import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.vo.ProjectMonthlyProgressReportQueryVO;
import com.unis.project.common.vo.ProjectMonthlyProgressReportVO;
import com.unis.project.server.dao.ProjectMonthlyProgressReportDao;
import com.unis.project.server.entity.ProjectMonthlyProgressReportDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectMonthlyProgressReportDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectMonthlyProgressReportDomain extends BaseDomain {

	@Autowired
	private ProjectMonthlyProgressReportDao projectMonthlyProgressReportDao;

	/**
	 * 获取进度月报列表
	 * @param projectMonthlyProgressReportQueryVO
	 * @return
	 */
	public List<ProjectMonthlyProgressReportVO> getProjectMonthlyProgressReportList(ProjectMonthlyProgressReportQueryVO projectMonthlyProgressReportQueryVO) {
		List<ProjectMonthlyProgressReportDO> projectMonthlyProgressReportDOList = projectMonthlyProgressReportDao.getProjectMonthlyProgressReportList(projectMonthlyProgressReportQueryVO);
		List<ProjectMonthlyProgressReportVO> projectMonthlyProgressReportVOList = new ArrayList<>();
		if (projectMonthlyProgressReportQueryVO.getJdydMonth() == null &&
				projectMonthlyProgressReportQueryVO.getJdydYear() == null &&
				projectMonthlyProgressReportQueryVO.getSftz() == null) {
			if (!(projectMonthlyProgressReportDOList != null && projectMonthlyProgressReportDOList.size() > 0)) {//无数据 生成一条本月月报数据
				ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = new ProjectMonthlyProgressReportVO();
				Integer year = DateUtil.getYearString();
				Integer month = DateUtil.getMonthString();
				Date deadline = null;
				if (month.intValue() == 2) {
					deadline = DateUtil.turnStrDateToJavaUtilDate(year.toString() + "-" + month.toString() + "-05 23:23:59", "yyyy-MM-dd hh:mm:ss");
				} else {
					deadline = DateUtil.turnStrDateToJavaUtilDate(year.toString() + "-0" + month.toString() + "-05 23:23:59", "yyyy-MM-dd hh:mm:ss");
				}
				projectMonthlyProgressReportVO.setJdydYear(year);
				projectMonthlyProgressReportVO.setJdydMonth(month);
				projectMonthlyProgressReportVO.setYbjzrq(deadline);
				this.insert(projectMonthlyProgressReportVO);
				projectMonthlyProgressReportDOList = projectMonthlyProgressReportDao.getProjectMonthlyProgressReportList(projectMonthlyProgressReportQueryVO);
			}
		}
		if (projectMonthlyProgressReportDOList != null && projectMonthlyProgressReportDOList.size() > 0){
			for (ProjectMonthlyProgressReportDO projectMonthlyProgressReportDO : projectMonthlyProgressReportDOList) {
				ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = new ProjectMonthlyProgressReportVO();
				LsBeanUtils.copyAllProperties(projectMonthlyProgressReportDO, projectMonthlyProgressReportVO);
				projectMonthlyProgressReportVOList.add(projectMonthlyProgressReportVO);
			}
		}
		return projectMonthlyProgressReportVOList;
	}

	/**
	 * 新增进度月报
	 * @param projectMonthlyProgressReportVO
	 * @return
	 */
	public ProjectMonthlyProgressReportVO insert(ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO) {
		ProjectMonthlyProgressReportDO projectMonthlyProgressReportDO = projectMonthlyProgressReportDao.getProjectMonthlyProgressReport(projectMonthlyProgressReportVO);
		if (projectMonthlyProgressReportDO == null) {
			String month = projectMonthlyProgressReportVO.getJdydMonth().toString();
			if (month.length() == 1) {
				month = "0" + month;
			}
			//项目进度月报id   YB+201910+001
			String prefix = "YB" + projectMonthlyProgressReportVO.getJdydYear().toString() + month;
			String xmjdybId = getMaxCodeById(projectMonthlyProgressReportDao.getMaxCodeById(prefix), prefix, 3);
			projectMonthlyProgressReportVO.setXmjdybId(xmjdybId);
			projectMonthlyProgressReportVO.setSftz(0);
			projectMonthlyProgressReportVO.setStatus(1);
			projectMonthlyProgressReportVO.setCreateDate(new Date());
			projectMonthlyProgressReportDO = new ProjectMonthlyProgressReportDO();
			LsBeanUtils.copyAllProperties(projectMonthlyProgressReportVO, projectMonthlyProgressReportDO);
			projectMonthlyProgressReportDao.insertSelective(projectMonthlyProgressReportDO);
		} else {
			projectMonthlyProgressReportVO.setXmjdybId(projectMonthlyProgressReportDO.getXmjdybId());
			this.update(projectMonthlyProgressReportVO);
		}
		return projectMonthlyProgressReportVO;
	}

	/**
	 * 根据ID获取进度月报
	 * @param xmjdybId
	 * @return
	 */
	public ProjectMonthlyProgressReportVO getProjectMonthlyProgressReportInfoById(String xmjdybId) {
		ProjectMonthlyProgressReportDO projectMonthlyProgressReportDO = projectMonthlyProgressReportDao.getProjectMonthlyProgressReportInfo(xmjdybId);
		if(projectMonthlyProgressReportDO == null) {
			return null;
		}
		ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = new ProjectMonthlyProgressReportVO();
		LsBeanUtils.copyAllProperties(projectMonthlyProgressReportDO, projectMonthlyProgressReportVO);
		return projectMonthlyProgressReportVO;
	}

	/**
	 * 更新进度月报
	 * @param projectMonthlyProgressReportVO
	 * @return
	 */
	public int update(ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO) {
		ProjectMonthlyProgressReportDO projectMonthlyProgressReportDO = projectMonthlyProgressReportDao.getProjectMonthlyProgressReportInfo(projectMonthlyProgressReportVO.getXmjdybId());
		if (projectMonthlyProgressReportDO == null) {
			return 0;
		}
		//截止时间为 xxxx-xx-xx 23:23:59
		Date sftzsj = DateUtil.turnStrDateToJavaUtilDate(DateUtil.getDateFormat(projectMonthlyProgressReportVO.getSftzsj(),"yyyy-MM-dd")+" 23:23:59","yyyy-MM-dd hh:mm:ss");
		projectMonthlyProgressReportVO.setSftzsj(sftzsj);
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectMonthlyProgressReportVO, projectMonthlyProgressReportDO);
		return projectMonthlyProgressReportDao.update(projectMonthlyProgressReportDO);
	}

	/**
	 * 获取当天截止日期的月报数据
	 * @return
	 */
	public ProjectMonthlyProgressReportVO getProjectMonthlyProgressReportByDate() {
		ProjectMonthlyProgressReportDO projectMonthlyProgressReportDO = projectMonthlyProgressReportDao.getProjectMonthlyProgressReportByDate();
		if (projectMonthlyProgressReportDO == null) {
			return null;
		}
		ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = new ProjectMonthlyProgressReportVO();
		LsBeanUtils.copyAllProperties(projectMonthlyProgressReportDO, projectMonthlyProgressReportVO);
		return projectMonthlyProgressReportVO;
	}
}
