package com.unis.project.server.domain;


import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.vo.ProjectProgressBriefingVO;
import com.unis.project.server.dao.ProjectProgressBriefingDao;
import com.unis.project.server.entity.ProjectProgressBriefingDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectProgressBriefingDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectProgressBriefingDomain extends BaseDomain {

	@Autowired
	private ProjectProgressBriefingDao ProjectProgressBriefingDao;

	@Autowired
	private FileDomain fileDomain;

	/**
	 * 新增项目进度简报信息
	 * @param projectProgressBriefingVO
	 * @return
	 */
	public ProjectProgressBriefingVO insert(ProjectProgressBriefingVO projectProgressBriefingVO) {
		ProjectProgressBriefingDO projectProgressBriefingDO = ProjectProgressBriefingDao.getProjectProgressBriefingInfo(projectProgressBriefingVO);
		if (projectProgressBriefingDO == null) {
			projectProgressBriefingDO = new ProjectProgressBriefingDO();
			String prefix = projectProgressBriefingVO.getXmsqId() + "JB"; // 项目进度简报id  项目申请id+JB+001
			String xmjdjbId = getMaxCodeById(ProjectProgressBriefingDao.getMaxCodeById(prefix), prefix, 3);
			projectProgressBriefingVO.setXmjdjbId(xmjdjbId);
			projectProgressBriefingVO.setStatus(1);
			projectProgressBriefingVO.setCreateDate(new Date());
			LsBeanUtils.copyAllProperties(projectProgressBriefingVO, projectProgressBriefingDO);
			ProjectProgressBriefingDao.insertSelective(projectProgressBriefingDO);
		} else {
			projectProgressBriefingVO.setXmjdjbId(projectProgressBriefingDO.getXmjdjbId());
			this.update(projectProgressBriefingVO);
		}
		return projectProgressBriefingVO;
	}

	/**
	 * 更新项目进度简报信息
	 * @param projectProgressBriefingVO
	 * @return
	 */
	public int update(ProjectProgressBriefingVO projectProgressBriefingVO) {
		String xmjdjbId = projectProgressBriefingVO.getXmjdjbId();
		ProjectProgressBriefingDO projectProgressBriefingDO = ProjectProgressBriefingDao.getProjectProgressBriefing(xmjdjbId);
		if (projectProgressBriefingDO == null) {
			return 0;
		}
		projectProgressBriefingDO = new ProjectProgressBriefingDO();
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectProgressBriefingVO, projectProgressBriefingDO);
		fileDomain.updateFileList(projectProgressBriefingVO.getXmjdjbList(),xmjdjbId);
		return ProjectProgressBriefingDao.update(projectProgressBriefingDO);
	}

	/**
	 * 查询详情
	 * @param xmsqId
	 * @return
	 */
	public List<ProjectProgressBriefingVO> getProjectMaterialDetailsListById(String xmsqId) {
		List<ProjectProgressBriefingVO> projectProgressBriefingVOList = ProjectProgressBriefingDao.getProjectMaterialDetailsListById(xmsqId);
		if (projectProgressBriefingVOList != null && projectProgressBriefingVOList.size() > 0) {
			for (ProjectProgressBriefingVO projectProgressBriefingVO : projectProgressBriefingVOList) {
				projectProgressBriefingVO.setXmjdjbList(fileDomain.getFileListBySjId(projectProgressBriefingVO.getXmjdjbId()));
			}
		}
		return projectProgressBriefingVOList;
	}

	/**
	 * 查询验收前当前月度数据
	 * @param xmjdybId
	 * @return
	 */
	public List<ProjectProgressBriefingVO> getProjectMaterialDetailsListByxmjdybId(String xmjdybId) {
		return ProjectProgressBriefingDao.getProjectMaterialDetailsListByxmjdybId(xmjdybId);
	}

	/**
	 * 查询当前月度数据对上报数据
	 * @param xmjdybId
	 * @return
	 */
	public List<ProjectProgressBriefingVO> getProjectMaterialDetailsListByxmjdzt(String xmjdybId, Integer xmjdzt) {
		ProjectProgressBriefingVO projectProgressBriefingVO = new ProjectProgressBriefingVO();
		projectProgressBriefingVO.setXmjdybId(xmjdybId);
		projectProgressBriefingVO.setXmjdzt(xmjdzt);
		return ProjectProgressBriefingDao.getProjectMaterialDetailsListByxmjdzt(projectProgressBriefingVO);
	}

	/**
	 * 获取待上报当天截止时间数据
	 * @return
	 */
	public List<String> getProjectProgressBriefingIdList() {
		return ProjectProgressBriefingDao.getProjectProgressBriefingIdList();
	}
}
