package com.unis.project.server.domain;

import com.alibaba.fastjson.JSON;
import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.constant.MaterialStatusConstant;
import com.unis.project.common.constant.ProjectStatusConstant;
import com.unis.project.common.vo.ProjectApplicationVO;
import com.unis.project.common.vo.ProjectMaterialDetailsQueryVO;
import com.unis.project.common.vo.ProjectProposalReportVO;
import com.unis.project.common.vo.backlog.BacklogAddVO;
import com.unis.project.common.vo.backlog.BacklogUpdateVO;
import com.unis.project.common.vo.backlog.JsonUtils;
import com.unis.project.common.vo.backlog.ReceiverCollectionVO;
import com.unis.project.server.dao.ProjectApplicationDao;
import com.unis.project.server.dao.ProjectProposalReportDao;
import com.unis.project.server.entity.ProjectApplicationDO;
import com.unis.project.server.entity.ProjectProposalReportDO;
import com.unis.project.server.service.mq.BacklogMQService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;

/**
 * @Author zoujieli
 * @Description
 * @Date 2019/10/25 17:37
 * Version 1.0
 */

@Component
public class ProjectProposalReportDomain extends BaseDomain{

    @Autowired
    private ProjectProposalReportDao projectProposalReportDao;

    @Autowired
    private ProjectApplicationDao projectApplicationDao;
    @Autowired
    private BacklogMQService mqService;

    @Autowired
    private ProjectMaterialDetailsDomain projectMaterialDetailsDomain;

    //项目文本类型：1、项目建议书。2、可研报告
    private static final Integer[] xmwblxList = {1,2};
    private static final String[] xmwblxNameList = {"JYS","BG"};

    /**
     * 项目建议书/可研报告-查询详情
     * @author 邹杰利
     * @param xmsqId
     * @param xmwblx
     * @return
     */
    public ProjectProposalReportVO getProjectProposalReportDetail(String xmsqId, Integer xmwblx) {
        ProjectProposalReportVO projectProposalReportVO = new ProjectProposalReportVO();
        projectProposalReportVO.setXmsqId(xmsqId);
        projectProposalReportVO.setXmwblx(xmwblx);
        ProjectProposalReportDO projectProposalReportDO = projectProposalReportDao.getProjectProposalReportInfo(projectProposalReportVO);
        if (projectProposalReportDO == null){
            return null;
        }
        String xmjysbgId = projectProposalReportDO.getXmjysbgId();
        LsBeanUtils.copyAllProperties(projectProposalReportDO, projectProposalReportVO);
        if (xmwblx.equals(xmwblxList[0])){
            projectProposalReportVO.setXmjysbgList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmjysbgId, MaterialStatusConstant.XMJYS,null,null)));
            projectProposalReportVO.setXmbgshList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmjysbgId, MaterialStatusConstant.JYSSH, null,null)));
        } else if (xmwblx.equals(xmwblxList[1])){
            projectProposalReportVO.setXmjysbgList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmjysbgId, MaterialStatusConstant.KYBG,null,null)));
            projectProposalReportVO.setXmbgshList(projectMaterialDetailsDomain.getProjectMaterialDetailsList(new ProjectMaterialDetailsQueryVO(xmjysbgId, MaterialStatusConstant.BGSH,null,null)));
        }
        return projectProposalReportVO;
    }

    /**
     * 项目建议书/可研报告-新增
     * @author 邹杰利
     * @param projectProposalReportVO
     * @return
     */
    public ProjectProposalReportVO insertProjectProposalReport(ProjectProposalReportVO projectProposalReportVO) {
        ProjectProposalReportDO projectProposalReportDO = projectProposalReportDao.getProjectProposalReportInfo(projectProposalReportVO);
        ProjectApplicationDO applicationVO = projectApplicationDao.selectByPrimaryKey(projectProposalReportVO
                .getXmsqId());
        if (projectProposalReportDO == null) {
            projectProposalReportDO = new ProjectProposalReportDO();
            String xmsqId = projectProposalReportVO.getXmsqId();
            Integer xmwblx = projectProposalReportVO.getXmwblx();
            String prefix = "";
            String xmjysbgId = "";
            int index = 0;
            while (index < xmwblxList.length) {
                if (xmwblxList[index].equals(xmwblx)) {
                    prefix = xmsqId + xmwblxNameList[index]; // 项目建议书报告id  项目申请id+xmwblxNameList[index]+001
                    xmjysbgId = getMaxCodeById(projectProposalReportDao.getMaxCodeById(prefix), prefix, 3);
                }
                index++;
            }
            projectProposalReportVO.setXmjysbgId(xmjysbgId);
            projectProposalReportVO.setXmsqId(xmsqId);
            projectProposalReportVO.setStatus(1);
            projectProposalReportVO.setCreateDate(new Date());
            LsBeanUtils.copyAllProperties(projectProposalReportVO, projectProposalReportDO);
            projectMaterialDetailsDomain.insertProjectMaterialDetailsList(projectProposalReportVO.getXmjysbgList(), xmjysbgId);
           int num =  projectProposalReportDao.insertSelective(projectProposalReportDO);
           if(num>0&& ProjectStatusConstant.PROPOSAL_SUBMITTED.getValue().equals(applicationVO.getXmzbzt())||ProjectStatusConstant.REPORT_SUBMITTED.getValue().equals(applicationVO.getXmzbzt())){
               //======================张新亮 添加代办 start========================
               System.out.println("*************进入创建待办************");
               BacklogAddVO record=new BacklogAddVO();
               record.buildAddVO(record);
               record.setSubmitter(projectProposalReportVO.getSubmitter());
               record.setSubmitterId(projectProposalReportVO.getSubmitterId());
               record.setCompanyName(projectProposalReportVO.getCompanyName());
               record.setItemQuery(projectProposalReportVO.getItemQuery());
               if(ProjectStatusConstant.PROPOSAL_SUBMITTED.getValue().equals(applicationVO.getXmzbzt())){
                   record.setItemId(projectProposalReportVO.getXmsqId()+"-01");
                   record.setItemStatus(Integer.valueOf(ProjectStatusConstant.PROPOSAL_SUBMITTED.getValue()));
                   record.setItemStatusName(ProjectStatusConstant.PROPOSAL_SUBMITTED.getName());
               }else{
                   record.setItemId(projectProposalReportVO.getXmsqId()+"-02");
                   record.setItemStatus(Integer.valueOf(ProjectStatusConstant.REPORT_SUBMITTED.getValue()));
                   record.setItemStatusName(ProjectStatusConstant.REPORT_SUBMITTED.getName());
               }

               record.setItemName(projectProposalReportVO.getItemName());
               record.setItemUrl(projectProposalReportVO.getUrl());
               record.setItemQueryHaveDone(projectProposalReportVO.getItemQueryHaveDone());
               record.setItemUrlHaveDone(projectProposalReportVO.getItemUrlHaveDone());

               // 另起线程执行待办
               new Thread(new Runnable() {
                   @Override
                   public void run() {
                       if(projectProposalReportVO.getUserList()!=null&&projectProposalReportVO.getUserList().size()>0){
                           for (ReceiverCollectionVO userVO : projectProposalReportVO.getUserList()) {
                               System.out.println("********************接收人*******************");
                               System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                               System.out.println("********************************************");
                               record.setReceiver(userVO.getUserName());
                               record.setReceiverId(userVO.getUserId());
                               // 需要将对象序列化成JSONObject
                               mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                           }
                       }
                   }
               }).start();
               //======================张新亮 添加代办 end========================
           }
        } else {
            projectProposalReportVO.setXmjysbgId(projectProposalReportDO.getXmjysbgId());
            this.update(projectProposalReportVO);
        }
        return projectProposalReportVO;
    }

    /**
     * 项目建议书/可研报告-更新
     * @author 邹杰利
     * @param projectProposalReportVO
     * @return
     */
    public int update(ProjectProposalReportVO projectProposalReportVO) {
        String xmjysbgId = projectProposalReportVO.getXmjysbgId();
        ProjectProposalReportDO projectProposalReportDO = projectProposalReportDao.getProjectProposalReportInfo(projectProposalReportVO);
        ProjectApplicationVO applicationVO = projectApplicationDao.getProjectApplicationInfo(projectProposalReportVO
                .getXmsqId());
        if (projectProposalReportDO == null) {
            return 0;
        }
        projectProposalReportDO = new ProjectProposalReportDO();
        LsBeanUtils.copyAllProperties(projectProposalReportVO,projectProposalReportDO);
        projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectProposalReportVO.getXmjysbgList(),xmjysbgId);
        projectMaterialDetailsDomain.updateProjectMaterialDetailsList(projectProposalReportVO.getXmbgshList(),xmjysbgId);
        int num = projectProposalReportDao.update(projectProposalReportDO);
        if(num>0&&(ProjectStatusConstant.PROPOSAL_SUBMITTED.getValue().equals(applicationVO.getXmzbzt())||ProjectStatusConstant.REPORT_SUBMITTED.getValue().equals(applicationVO.getXmzbzt()))){
            //======================张新亮 添加代办 start========================
            System.out.println("*************进入创建待办************");
            BacklogAddVO record=new BacklogAddVO();
            record.buildAddVO(record);
            record.setItemQuery(projectProposalReportVO.getItemQuery());
            record.setItemQueryHaveDone(projectProposalReportVO.getItemQueryHaveDone());
            record.setItemUrlHaveDone(projectProposalReportVO.getItemUrlHaveDone());
            if(ProjectStatusConstant.PROPOSAL_SUBMITTED.getValue().equals(applicationVO.getXmzbzt())){
                record.setItemId(projectProposalReportVO.getXmjysbgId()+"-01");
                record.setItemStatus(Integer.valueOf(ProjectStatusConstant.PROPOSAL_SUBMITTED.getValue()));
                record.setItemStatusName(ProjectStatusConstant.PROPOSAL_SUBMITTED.getName());
            }else{
                record.setItemId(projectProposalReportVO.getXmjysbgId()+"-02");
                record.setItemStatus(Integer.valueOf(ProjectStatusConstant.REPORT_SUBMITTED.getValue()));
                record.setItemStatusName(ProjectStatusConstant.REPORT_SUBMITTED.getName());
            }
            record.setItemName(projectProposalReportVO.getItemName());
            record.setItemUrl(projectProposalReportVO.getUrl());

            // 另起线程执行待办
            new Thread(new Runnable() {
                @Override
                public void run() {
                    if(projectProposalReportVO.getUserList()!=null&&projectProposalReportVO.getUserList().size()>0){
                        for (ReceiverCollectionVO userVO : projectProposalReportVO.getUserList()) {
                            System.out.println("********************接收人*******************");
                            System.out.println("-----" + userVO.getUserName() + "-------" + userVO.getUserId());
                            System.out.println("********************************************");
                            record.setReceiver(userVO.getUserName());
                            record.setReceiverId(userVO.getUserId());
                            // 需要将对象序列化成JSONObject
                            mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(record)), "insert");
                        }
                    }
                }
            }).start();
            //======================张新亮 添加代办 end========================
        }
        if(num>0){
            if(projectProposalReportVO.getPsjgzt()!=null&&(ProjectStatusConstant.PROPOSAL_APPROVED.getValue().equals
                    (applicationVO.getXmzbzt())||ProjectStatusConstant.REPORT_APPROVED.getValue().equals(applicationVO.getXmzbzt()))){
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                updateVO.setHandler(projectProposalReportVO.getRefresher());
                updateVO.setHandlerId(projectProposalReportVO.getRefresherCode());
                if(ProjectStatusConstant.PROPOSAL_APPROVED.getValue().equals
                        (applicationVO.getXmzbzt())){
                    updateVO.setItemId(projectProposalReportVO.getXmsqId()+"-01");
                    updateVO.setItemName("项目名称为（" +projectProposalReportVO.getXmmc()+"）的项目建议书申请已经批复");
                    updateVO.setItemStatus(Integer.valueOf(ProjectStatusConstant.PROPOSAL_APPROVED.getValue()));
                    updateVO.setItemStatusName(ProjectStatusConstant.PROPOSAL_APPROVED.getName());
                }else {
                    updateVO.setItemId(projectProposalReportVO.getXmsqId()+"-02");
                    updateVO.setItemName("项目名称为（" +projectProposalReportVO.getXmmc()+"）的可研报告申请已经批复");
                    updateVO.setItemStatus(Integer.valueOf(ProjectStatusConstant.REPORT_APPROVED.getValue()));
                    updateVO.setItemStatusName(ProjectStatusConstant.REPORT_APPROVED.getName());
                }

             /*   updateVO.setItemStatus(Integer.valueOf(projectProposalReportVO.getPsjgzt()));
                if("0".equals(projectProposalReportVO.getPsjgzt())){
                    updateVO.setItemStatusName("驳回");
                }else {
                    updateVO.setItemStatusName("通过");
                }*/
                mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");

            }
         /*   if(projectProposalReportVO.getPsjgzt()!=null&&ProjectStatusConstant.PROPOSAL_APPROVED.getValue().equals
                    (applicationVO.getXmzbzt())){
                BacklogUpdateVO updateVO = new BacklogUpdateVO();
                updateVO.buildUpdateVO(updateVO);
                updateVO.setHandler(projectProposalReportVO.getRefresher());
                updateVO.setHandlerId(projectProposalReportVO.getRefresherCode());
                updateVO.setItemStatus(Integer.valueOf(projectProposalReportVO.getPsjgzt()));
                if("0".equals(projectProposalReportVO.getPsjgzt())){
                    updateVO.setItemStatusName("驳回");
                }else {
                    updateVO.setItemStatusName("通过");
                }
                mqService.sendMsg(JSON.parseObject(JsonUtils.serialize(updateVO)), "update");

            }*/
        }
        return num;
    }
}
