package com.unis.project.server.domain;

import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.project.common.vo.ProjectTemplateQueryVO;
import com.unis.project.common.vo.ProjectTemplateVO;
import com.unis.project.server.dao.ProjectTemplateDao;
import com.unis.project.server.entity.ProjectTemplateDO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ProjectTemplateDomain
 * @ProjectName 持久化
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Component
public class ProjectTemplateDomain extends BaseDomain {

	@Autowired
	private ProjectTemplateDao projectTemplateDao;

	@Autowired
	private FileDomain fileDomain;

	/**
	 * 查询列表
	 * @param projectTemplateQueryVO
	 * @return
	 */
	public List<ProjectTemplateVO> getProjectTemplateList(ProjectTemplateQueryVO projectTemplateQueryVO) {
		return projectTemplateDao.getProjectTemplateList(projectTemplateQueryVO);
	}

	/**
	 * 新增项目模版
	 * @param projectTemplateVO
	 * @return
	 */
	public ProjectTemplateVO insert(ProjectTemplateVO projectTemplateVO) {
		//数据id  模版FE+20190830+001
		String prefix = "MB"+ DateUtil.getDate();
		String xmmbId = getMaxCodeById(projectTemplateDao.getMaxCodeById(prefix),prefix,3);
		projectTemplateVO.setXmmbId(xmmbId);
		projectTemplateVO.setStatus(1);
		projectTemplateVO.setCreateDate(new Date());
		ProjectTemplateDO projectTemplateDO = new ProjectTemplateDO();
		LsBeanUtils.copyAllProperties(projectTemplateVO, projectTemplateDO);
		fileDomain.insertFileList(projectTemplateVO.getTemplateFileList(),xmmbId);
		projectTemplateDao.insertSelective(projectTemplateDO);
		return projectTemplateVO;
	}

	/**
	 * 根据ID获取项目模版
	 * @param xmmbId
	 * @return
	 */
	public ProjectTemplateVO getProjectTemplateInfoById(String xmmbId) {
		ProjectTemplateDO projectTemplateDO = projectTemplateDao.getProjectTemplateInfo(xmmbId);
		if(projectTemplateDO == null) {
			return null;
		}
		ProjectTemplateVO projectTemplateVO = new ProjectTemplateVO();
		LsBeanUtils.copyAllProperties(projectTemplateDO, projectTemplateVO);
		projectTemplateVO.setTemplateFileList(fileDomain.getFileListBySjId(projectTemplateDO.getXmmbId()));
		return projectTemplateVO;
	}

	/**
	 * 更新项目模版
	 * @param projectTemplateVO
	 * @return
	 */
	public int update(ProjectTemplateVO projectTemplateVO) {
		ProjectTemplateDO projectTemplateDO = projectTemplateDao.getProjectTemplateInfo(projectTemplateVO.getXmmbId());
		if (projectTemplateDO == null) {
			return 0;
		}
		//进行传递参数copy
		LsBeanUtils.copyAllProperties(projectTemplateVO, projectTemplateDO);
		fileDomain.updateFileList(projectTemplateVO.getTemplateFileList(),projectTemplateVO.getXmmbId());
		return projectTemplateDao.update(projectTemplateDO);
	}

}
