package com.unis.project.server.scheduled;

import com.unis.common.utils.DateUtil;
import com.unis.project.common.constant.ProjectStatusConstant;
import com.unis.project.common.vo.ProjectApplicationVO;
import com.unis.project.common.vo.ProjectMonthlyProgressReportQueryVO;
import com.unis.project.common.vo.ProjectMonthlyProgressReportVO;
import com.unis.project.common.vo.ProjectProgressBriefingVO;
import com.unis.project.server.domain.ProjectApplicationDomain;
import com.unis.project.server.domain.ProjectMonthlyProgressReportDomain;
import com.unis.project.server.domain.ProjectProgressBriefingDomain;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * @author WangZL
 * @version 1.0
 * @Title ScheduledService
 * @ProjectName 定时任务 ScheduledService
 * @Description  TODO
 * @date 2019/07/22 17点26分
 */
@Slf4j
@Component
public class ScheduledService {

    @Autowired
    private ProjectApplicationDomain projectApplicationDomain;

    @Autowired
    private ProjectProgressBriefingDomain projectProgressBriefingDomain;

    @Autowired
    private ProjectMonthlyProgressReportDomain projectMonthlyProgressReportDomain;

    private static final Integer NOT_PEPORTED = 3;//项目进度状态：未上报

    /**
     * 每月月初0点5分执行此定时任务 生成心进度月报数据 同时推送到进度简报
     * @return
     */
    @Scheduled(cron="0 5 0 1 * ?")
    //@Scheduled(cron="0 */1 * * * ?")
    public void saveProjectMonthlyProgressReport() {
        ProjectMonthlyProgressReportVO projectMonthlyProgressReportVO = null;
        Integer year = DateUtil.getYearString();
        Integer month = DateUtil.getMonthString();
        Integer nextYear = 0;
        Integer nextMonth = 0;
        if (month == 12){
            nextYear = year;
            nextYear++;
            nextMonth = 1;
        } else {
            nextYear = year;
            nextMonth = month + 1;
        }
        String yearString = year.toString();
        String monthString = month.toString();
        String nextYearString = nextYear.toString();
        String nextMonthString = nextMonth.toString();
        ProjectMonthlyProgressReportQueryVO projectMonthlyProgressReportQueryVO = new ProjectMonthlyProgressReportQueryVO();
        projectMonthlyProgressReportQueryVO.setJdydYear(nextYear);
        projectMonthlyProgressReportQueryVO.setJdydMonth(nextMonth);
        log.info("===============  Execute 注意：扫描下月月度数据开始！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
        List<ProjectMonthlyProgressReportVO> projectMonthlyProgressReportVOList = projectMonthlyProgressReportDomain.getProjectMonthlyProgressReportList(projectMonthlyProgressReportQueryVO);
        if (projectMonthlyProgressReportVOList != null && projectMonthlyProgressReportVOList.size()>0){
            this.saveProjectProgressBriefing(projectMonthlyProgressReportVOList.get(0).getXmjdybId());
            log.info("========  下月数据"+nextYearString+"年"+nextMonthString+"月已存在！  ========",DateUtil.getDateTime());
            log.info("===============  Execute 注意：扫描下月月度数据结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
        } else {
            projectMonthlyProgressReportVO = new ProjectMonthlyProgressReportVO();
            projectMonthlyProgressReportVO.setJdydYear(nextYear);
            projectMonthlyProgressReportVO.setJdydMonth(nextMonth);
            projectMonthlyProgressReportVO.setYbjzrq(this.infoDate(nextYear,nextMonth));
            ProjectMonthlyProgressReportVO projectMonthlyProgressReport = projectMonthlyProgressReportDomain.insert(projectMonthlyProgressReportVO);
            this.saveProjectProgressBriefing(projectMonthlyProgressReport.getXmjdybId());
            log.info("========  下月数据"+nextYearString+"年"+nextMonthString+"月生成成功！  ========",DateUtil.getDateTime());
            log.info("===============  Execute 注意：扫描下月月度数据结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
            log.info("===============  Execute 注意：扫描本月月度数据开始！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
            projectMonthlyProgressReportQueryVO = new ProjectMonthlyProgressReportQueryVO();
            projectMonthlyProgressReportQueryVO.setJdydYear(year);
            projectMonthlyProgressReportQueryVO.setJdydMonth(month);
            List<ProjectMonthlyProgressReportVO> projectMonthlyProgressReportList = projectMonthlyProgressReportDomain.getProjectMonthlyProgressReportList(projectMonthlyProgressReportQueryVO);
            if (projectMonthlyProgressReportList != null && projectMonthlyProgressReportList.size() > 0){
                this.saveProjectProgressBriefing(projectMonthlyProgressReportList.get(0).getXmjdybId());
                log.info("========  本月数据"+yearString+"年"+monthString+"月已存在！  ========"+DateUtil.getDateTime(),DateUtil.getDateTime());
                log.info("===============  Execute 注意：扫描本月月度数据结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
            } else {
                log.info("========  本月月度数据不存在  ========"+DateUtil.getDateTime(),DateUtil.getDateTime());
                projectMonthlyProgressReportVO = new ProjectMonthlyProgressReportVO();
                projectMonthlyProgressReportVO.setJdydYear(year);
                projectMonthlyProgressReportVO.setJdydMonth(month);
                projectMonthlyProgressReportVO.setYbjzrq(this.infoDate(year,month));
                ProjectMonthlyProgressReportVO projectMonthlyProgress = projectMonthlyProgressReportDomain.insert(projectMonthlyProgressReportVO);
                this.saveProjectProgressBriefing(projectMonthlyProgress.getXmjdybId());
                log.info("========  本月数据"+yearString+"年"+monthString+"月生成成功！  ========"+DateUtil.getDateTime(),DateUtil.getDateTime());
                log.info("===============  Execute 注意：扫描本月月度数据结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
            }
        }
        log.info("===============  Execute 注意：本月进度月报扫描结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
    }

    /**
     * 每天晚上11点查看已发布项目信息的截止日期是否今天过期 是今天将建议书未提交的立项项目改为已截止
     * @return
     */
    @Scheduled(cron="0 0 23 * * ?")
    public void projectApplicationDate() {
        ProjectApplicationVO projectApplicationVO = null;
        log.info("===============  Execute 注意：扫描本日项目申请条件截止时间开始！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
        //获取当日截止时间符合要求的项目申请id列表
        List<String> xmsqIdList = projectApplicationDomain.getProjectInfoDate();
        if (xmsqIdList != null && xmsqIdList.size() > 0){
            for (String xmsqId : xmsqIdList) {
                projectApplicationVO = new ProjectApplicationVO();
                projectApplicationVO.setXmsqId(xmsqId);
                projectApplicationVO.setXmlxzt(ProjectStatusConstant.CLOSED.getValue());
                projectApplicationVO.setRefreshDate(new Date());
                projectApplicationDomain.update(projectApplicationVO);
            }
        }
        log.info("===============  Execute 注意：扫描本日项目申请条件截止时间结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
        log.info("===============  Execute 注意：本日项目申请条件扫描结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
    }

    /**
     * 每天晚上11点半查看本日进度月报的截止日期 改变项目进度简报状态
     * @return
     */
    @Scheduled(cron="0 30 23 * * ?")
    public void projectProgressBriefingDate() {
        ProjectProgressBriefingVO projectProgressBriefingVO = null;
        log.info("===============  Execute 注意：扫描本日进度简报数据开始！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
        List<String> xmjdjbIdList = projectProgressBriefingDomain.getProjectProgressBriefingIdList();
        if (xmjdjbIdList != null && xmjdjbIdList.size() > 0) {
            log.info("本日月度截止时间到期的进度简报数据条数："+String.valueOf(xmjdjbIdList.size()),DateUtil.getDateTime());
            for (String xmjdjbId : xmjdjbIdList) {
                projectProgressBriefingVO = new ProjectProgressBriefingVO();
                projectProgressBriefingVO.setXmjdjbId(xmjdjbId);
                projectProgressBriefingVO.setXmjdzt(NOT_PEPORTED);//更新状态为未上报
                projectProgressBriefingDomain.update(projectProgressBriefingVO);
            }
            log.info("本日月度截止时间到期的进度简报数据全更改状态完毕！"+DateUtil.getDateTime(),DateUtil.getDateTime());
        }
        log.info("===============  Execute 注意：扫描本日进度简报数据结束！============="+DateUtil.getDateTime(),DateUtil.getDateTime());
    }

    /**
     * 初始截止时间为xxxx-xx-05 23:23:59
     * @param year
     * @param month
     * @return
     */
    public Date infoDate(Integer year, Integer month){
        Date date = null;
        if (month.intValue() == 2){
            date = DateUtil.turnStrDateToJavaUtilDate(year.toString()+"-"+month.toString()+"-05 23:23:59","yyyy-MM-dd hh:mm:ss");
        } else {
            date = DateUtil.turnStrDateToJavaUtilDate(year.toString()+"-0"+month.toString()+"-05 23:23:59","yyyy-MM-dd hh:mm:ss");
        }
        return date;
    }

    /**
     * 推送保存简报数据
     * @param xmjdybId
     * @return
     */
    public void saveProjectProgressBriefing(String xmjdybId){
        //获取资金申请提交后和验收申请提交前的项目申请id
        List<String> xmsqIdList = projectApplicationDomain.getProjectApplicationIdList();
        //遍历推送进度简报数据
        if (xmsqIdList != null && xmsqIdList.size() > 0){
            for (String xmsqId : xmsqIdList) {
                ProjectProgressBriefingVO projectProgressBriefingVO = new ProjectProgressBriefingVO();
                projectProgressBriefingVO.setXmjdybId(xmjdybId);
                projectProgressBriefingVO.setXmsqId(xmsqId);
                projectProgressBriefingDomain.insert(projectProgressBriefingVO);
            }
        }
    }
}
